#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   ukrainian.py
@Time    :   2020/09/07
@Author  :   Montyzzz
@Version :   1.0
@Contact :   ---
@Desc    :   
'''


class LangUkrainian(object):
    SETTING = "НАЛАШТУВАННЯ"
    VALUE = "ЗНАЧЕННЯ"
    SETTING_DOWNLOAD_PATH = "Шлях завантаження"
    SETTING_ONLY_M4A = "Перетворити mp4 на m4a"
    SETTING_ADD_EXPLICIT_TAG = "Додати тег Нецензурно"
    SETTING_ADD_HYPHEN = "Додати дефіс"
    SETTING_ADD_YEAR = "Додати рік перед ім'ям папки-альбому"
    SETTING_USE_TRACK_NUM = "Додати номер треку"
    SETTING_AUDIO_QUALITY = "Якість аудіо"
    SETTING_VIDEO_QUALITY = "Якість відео"
    SETTING_CHECK_EXIST = "Перевіряти наявність"
    SETTING_ARTIST_BEFORE_TITLE = "Виконавець перед назвою треку"
    SETTING_ALBUMID_BEFORE_FOLDER = "ID перед назвою теки"
    SETTING_INCLUDE_EP = "Включити сингл і міньйон"
    SETTING_SAVE_COVERS = "Зберегти обкладинки"
    SETTING_LANGUAGE = "Мова"
    SETTING_USE_PLAYLIST_FOLDER = "Use playlist folder"
    SETTING_MULITHREAD_DOWNLOAD = "Multi thread download"
    SETTING_ALBUM_FOLDER_FORMAT = "Album folder format"
    SETTING_TRACK_FILE_FORMAT = "Track file format"
    SETTING_SHOW_PROGRESS = "Show progress"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Save AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Add lyrics"
    SETTING_LYRICS_SERVER_PROXY = "Lyrics server proxy"
    SETTING_PATH = "Settings path"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "ВИБІР"
    FUNCTION = "ФУНКЦІЇ"
    CHOICE_ENTER = "Ввід"
    CHOICE_ENTER_URLID = "Ввід 'Url/ID':"
    CHOICE_EXIT = "Вихід"
    CHOICE_LOGIN = "Check AccessToken"
    CHOICE_SETTINGS = "Налаштування"
    CHOICE_SET_ACCESS_TOKEN = "Застосувати AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "Завантажити за URL-адресою або ідентифікатором"
    CHOICE_LOGOUT = "Logout"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[ПОМИЛКА]"
    PRINT_INFO = "[ІНФОРМАЦІЯ]"
    PRINT_SUCCESS = "[УСПІХ]"

    PRINT_ENTER_CHOICE = "Вибір вводу:"
    PRINT_LATEST_VERSION = "Остання версія:"
    # PRINT_USERNAME = "ім'я користувача:"
    # PRINT_PASSWORD = "пароль:"

    CHANGE_START_SETTINGS = "Налаштування запуску('0'-повернення,'1'-так):"
    CHANGE_DOWNLOAD_PATH = "Шлях завантаження('0' не змінювати):"
    CHANGE_AUDIO_QUALITY = "Якість аудіо('0'-Звичайна,'1'-Висока,'2'-HiFi,'3'-MQA):"
    CHANGE_VIDEO_QUALITY = "Якість відео(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Перетворити mp4 на m4a('0'-Ні,'1'-Так):"
    CHANGE_ADD_EXPLICIT_TAG = "Додати тег 'Нецензурно' ('0'-Ні,'1'-Так):"
    CHANGE_ADD_HYPHEN = "Використати дефіс замість пробілів в іменах файлів('0'-Ні,'1'-Так):"
    CHANGE_ADD_YEAR = "Додавати рік до назв тек альбомів ('0'-Ні,'1'-Так):"
    CHANGE_USE_TRACK_NUM = "Додавати номер доріжки перед назвами файлів ('0'-Ні,'1'-Так):"
    CHANGE_CHECK_EXIST = "Перевіряти наявний файл перед завантаженням треку ('0'-Ні,'1'-Так):"
    CHANGE_ARTIST_BEFORE_TITLE = "Додати ім’я виконавця перед заголовком треку ('0'-Ні,'1'-Так):"
    CHANGE_INCLUDE_EP = "Включати сингли та міньйони під час завантаження альбомів виконавця ('0'-Ні,'1'-Так):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Додати ідентифікатор перед текою альбому ('0'-Ні,'1'-Так):"
    CHANGE_SAVE_COVERS = "Зберігати обкладинки ('0'-Ні,'1'-Так):"
    CHANGE_LANGUAGE = "Обрати мову"
    CHANGE_ALBUM_FOLDER_FORMAT = "Album folder format('0' not modify):"
    CHANGE_TRACK_FILE_FORMAT = "Track file format('0' not modify):"
    CHANGE_SHOW_PROGRESS = "Show progress('0'-No,'1'-Yes):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Save AlbumInfo.txt('0'-No,'1'-Yes):"
    CHANGE_ADD_LYRICS = "Add lyrics('0'-No,'1'-Yes):"
    CHANGE_LYRICS_SERVER_PROXY = "Lyrics server proxy('0' not modify):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Starting login process..."
    AUTH_LOGIN_CODE = "Your login code is {}"
    AUTH_NEXT_STEP = "Go to {} within the next {} to complete setup."
    AUTH_WAITING = "Waiting for authorization..."
    AUTH_TIMEOUT = "Operation timed out."

    MSG_VALID_ACCESSTOKEN = "AccessToken good for {}."
    MSG_INVAILD_ACCESSTOKEN = "Expired AccessToken. Attempting to refresh it."
    MSG_PATH_ERR = "Невірний шлях!"
    MSG_INPUT_ERR = "Помилка введення!"

    MODEL_ALBUM_PROPERTY = "ALBUM-PROPERTY"
    MODEL_TRACK_PROPERTY = "TRACK-PROPERTY"
    MODEL_VIDEO_PROPERTY = "VIDEO-PROPERTY"
    MODEL_ARTIST_PROPERTY = "ARTIST-PROPERTY"
    MODEL_PLAYLIST_PROPERTY = "PLAYLIST-PROPERTY"

    MODEL_TITLE = 'Назва'
    MODEL_TRACK_NUMBER = 'Номер доріжки'
    MODEL_VIDEO_NUMBER = 'Номер відео'
    MODEL_RELEASE_DATE = 'Дата релізу'
    MODEL_VERSION = 'Версія'
    MODEL_EXPLICIT = 'Нецензурно'
    MODEL_ALBUM = 'Альбом'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Ім\'я'
    MODEL_TYPE = 'Тип'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   french.py
@Time    :   2020/10/25
@Authors :   flamme-demon & joyel24
@Version :   0.3
@Contact :   
@Desc    :   
'''


class LangFrench(object):
    SETTING = "RÉGLAGES"
    VALUE = "VALEUR"
    SETTING_DOWNLOAD_PATH = "Emplacement des téléchargements"
    SETTING_ONLY_M4A = "Convertir mp4 en m4a"
    SETTING_ADD_EXPLICIT_TAG = "Ajout du tag Explicit - Dossier"
    SETTING_ADD_HYPHEN = "Ajouter un trait d'union"
    SETTING_ADD_YEAR = "Ajouter l'année avant le nom de l'album - Dossier"
    SETTING_USE_TRACK_NUM = "Ajouter le numéro de piste de l'album"
    SETTING_AUDIO_QUALITY = "Qualité Audio"
    SETTING_VIDEO_QUALITY = "Qualité Video"
    SETTING_CHECK_EXIST = "Vérifier l'existence"
    SETTING_ARTIST_BEFORE_TITLE = "Nom de l'artiste avant le titre du morceau - Fichier"
    SETTING_ALBUMID_BEFORE_FOLDER = "Id avant le nom d'album - Dossier"
    SETTING_INCLUDE_EP = "Inclure les singles & EPs"
    SETTING_SAVE_COVERS = "Sauvegarder les couvertures"
    SETTING_LANGUAGE = "Langue"
    SETTING_USE_PLAYLIST_FOLDER = "Utiliser dossier de playlist"
    SETTING_MULITHREAD_DOWNLOAD = "Téléchargement multithread"
    SETTING_ALBUM_FOLDER_FORMAT = "Format du dossier d'album"
    SETTING_TRACK_FILE_FORMAT = "Format du fichier de tracklist"
    SETTING_SHOW_PROGRESS = "Afficher la Progression"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Save AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Add lyrics"
    SETTING_LYRICS_SERVER_PROXY = "Lyrics server proxy"
    SETTING_PATH = "Settings path"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "CHOIX"
    FUNCTION = "FONCTION"
    CHOICE_ENTER = "Saisir"
    CHOICE_ENTER_URLID = "Saisir 'Url/ID':"
    CHOICE_EXIT = "Quitter"
    CHOICE_LOGIN = "Check AccessToken"
    CHOICE_SETTINGS = "Réglages"
    CHOICE_SET_ACCESS_TOKEN = "Définir le jeton d'accès"
    CHOICE_DOWNLOAD_BY_URL = "Téléchargement par url ou id"
    CHOICE_LOGOUT = "Logout"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[ERR]"
    PRINT_INFO = "[INFO]"
    PRINT_SUCCESS = "[SUCCES]"

    PRINT_ENTER_CHOICE = "Saisir le choix:"
    PRINT_LATEST_VERSION = "Dernière version:"
    # PRINT_USERNAME = "Utilisateur:"
    # PRINT_PASSWORD = "Mot de passe:"

    CHANGE_START_SETTINGS = "Commencer les réglages ('0'-Retour,'1'-Oui):"
    CHANGE_DOWNLOAD_PATH = "Emplacement des téléchargements('0' ne pas modifier):"
    CHANGE_AUDIO_QUALITY = "Qualité audio('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "Qualité Video(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Convertir mp4 en m4a('0'-Non,'1'-Oui):"
    CHANGE_ADD_EXPLICIT_TAG = "Ajout du tag Explicit - Fichier('0'-Non,'1'-Oui):"
    CHANGE_ADD_HYPHEN = "Utilisez des traits d'union au lieu d'espaces dans les noms de fichiers('0'-Non,'1'-Oui):"
    CHANGE_ADD_YEAR = "Ajouter l'année aux noms des dossiers des albums('0'-Non,'1'-Oui):"
    CHANGE_USE_TRACK_NUM = "Ajouter le numéro de piste avant le nom des fichiers('0'-Non,'1'-Oui):"
    CHANGE_CHECK_EXIST = "Vérifier l'existence du fichier avant le téléchargement('0'-Non,'1'-Oui):"
    CHANGE_ARTIST_BEFORE_TITLE = "Ajouter le nom de l'artiste avant le titre de la piste('0'-Non,'1'-Oui):"
    CHANGE_INCLUDE_EP = "Inclure les singles et les EPs lors du téléchargement des albums d'un artiste('0'-Non,'1'-Oui):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Ajouter un identifiant avant le dossier album('0'-Non,'1'-Oui):"
    CHANGE_SAVE_COVERS = "Sauvegarder les couvertures('0'-Non,'1'-Oui):"
    CHANGE_LANGUAGE = "Sélectionnez une langue"
    CHANGE_ALBUM_FOLDER_FORMAT = "Format du dossier d'album('0' ne pas modifier):"
    CHANGE_TRACK_FILE_FORMAT = "Format du fichier de tracklist('0' ne pas modifier):"
    CHANGE_SHOW_PROGRESS = "Afficher la progression('0'-Non,'1'-Oui):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Save AlbumInfo.txt('0'-No,'1'-Yes):"
    CHANGE_ADD_LYRICS = "Add lyrics('0'-No,'1'-Yes):"
    CHANGE_LYRICS_SERVER_PROXY = "Lyrics server proxy('0' not modify):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Starting login process..."
    AUTH_LOGIN_CODE = "Your login code is {}"
    AUTH_NEXT_STEP = "Go to {} within the next {} to complete setup."
    AUTH_WAITING = "Waiting for authorization..."
    AUTH_TIMEOUT = "Operation timed out."

    MSG_VALID_ACCESSTOKEN = "AccessToken good for {}."
    MSG_INVAILD_ACCESSTOKEN = "Expired AccessToken. Attempting to refresh it."
    MSG_PATH_ERR = "Erreur du chemin d'accès"
    MSG_INPUT_ERR = "Erreur de saisie !"

    MODEL_ALBUM_PROPERTY = "PROPRIETES-ALBUM"
    MODEL_TRACK_PROPERTY = "PROPRIETES-PISTES-AUDIO"
    MODEL_VIDEO_PROPERTY = "PROPRIETES-VIDEO"
    MODEL_ARTIST_PROPERTY = "PROPRIETES-ARTISTE"
    MODEL_PLAYLIST_PROPERTY = "PROPERTES-PLAYLIST"

    MODEL_TITLE = 'Titre'
    MODEL_TRACK_NUMBER = 'Numéro de piste'
    MODEL_VIDEO_NUMBER = 'Numéro de la vidéo'
    MODEL_RELEASE_DATE = 'Date de publication'
    MODEL_VERSION = 'Version'
    MODEL_EXPLICIT = 'Explicit'
    MODEL_ALBUM = 'Album'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Nom'
    MODEL_TYPE = 'Type'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   italian.py
@Time    :   2020/08/20
@Author  :   Normando
@Version :   1.0
@Contact :   normando@me.com
@Desc    :
'''


class LangItalian(object):
    SETTING = "IMPOSTAZIONI"
    VALUE = "VALORE"
    SETTING_DOWNLOAD_PATH = "Percorso Download"
    SETTING_ONLY_M4A = "Convertire mp4 in m4a"
    SETTING_ADD_EXPLICIT_TAG = "Aggiungere tag 'Contenuto esplicito'"
    SETTING_ADD_HYPHEN = "Aggiungere trattino"
    SETTING_ADD_YEAR = "Aggiungere anno nella cartella album"
    SETTING_USE_TRACK_NUM = "Aggiungere numero traccia utente"
    SETTING_AUDIO_QUALITY = "Qualità Audio"
    SETTING_VIDEO_QUALITY = "Video Video"
    SETTING_CHECK_EXIST = "Controlla esistenza"
    SETTING_ARTIST_BEFORE_TITLE = "Nome artista prima del titolo della traccia"
    SETTING_ALBUMID_BEFORE_FOLDER = "Numero Id nell cartella album"
    SETTING_INCLUDE_EP = "Includere singolo&ep"
    SETTING_SAVE_COVERS = "Salva copertine"
    SETTING_LANGUAGE = "Lingua"
    SETTING_USE_PLAYLIST_FOLDER = "Use playlist folder"
    SETTING_MULITHREAD_DOWNLOAD = "Multi thread download"
    SETTING_ALBUM_FOLDER_FORMAT = "Album folder format"
    SETTING_TRACK_FILE_FORMAT = "Track file format"
    SETTING_SHOW_PROGRESS = "Show progress"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Save AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Add lyrics"
    SETTING_LYRICS_SERVER_PROXY = "Lyrics server proxy"
    SETTING_PATH = "Settings path"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "SCELTA"
    FUNCTION = "FUNZIONE"
    CHOICE_ENTER = "Inserire"
    CHOICE_ENTER_URLID = "Inserire 'Url/ID':"
    CHOICE_EXIT = "Uscita"
    CHOICE_LOGIN = "Check AccessToken"
    CHOICE_SETTINGS = "Impostazioni"
    CHOICE_SET_ACCESS_TOKEN = "Imposta AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "Scarica per URL o Id"
    CHOICE_LOGOUT = "Logout"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[ERR]"
    PRINT_INFO = "[INFO]"
    PRINT_SUCCESS = "[SUCCESSO]"

    PRINT_ENTER_CHOICE = "Inserire scelta:"
    PRINT_LATEST_VERSION = "Ultima versione:"
    # PRINT_USERNAME = "username:"
    # PRINT_PASSWORD = "password:"

    CHANGE_START_SETTINGS = "Impostazioni all'avvio ('0'-Ritorna,'1'-Sì):"
    CHANGE_DOWNLOAD_PATH = "Percorso Download ('0' non modificare):"
    CHANGE_AUDIO_QUALITY = "Qualità Audio ('0'-Normale, '1'-Alta, '2'-HiFi, '3'-Master):"
    CHANGE_VIDEO_QUALITY = "Qualità Video (1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Convertire mp4 in m4a ('0'-No,'1'-):"
    CHANGE_ADD_EXPLICIT_TAG = "Aggiungi tag 'Contenuto Esplicito' ai nomi dei file ('0'-No,'1'-Sì):"
    CHANGE_ADD_HYPHEN = "Usare trattini al posto degli spazi nei nomi dei file ('0'-No,'1'-Sì):"
    CHANGE_ADD_YEAR = "Aggiungere l'anno al nome della cartella dell'album ('0'-No,'1'-Sì):"
    CHANGE_USE_TRACK_NUM = "Aggiungere il numero traccia prima del nome dei file ('0'-No,'1'-Sì):"
    CHANGE_CHECK_EXIST = "Controllare se il file esiste prima di scaricare la traccia ('0'-No,'1'-Sì):"
    CHANGE_ARTIST_BEFORE_TITLE = "Aggiungere il nome dell'artista prima del titolo della traccia ('0'-No,'1'-Sì):"
    CHANGE_INCLUDE_EP = "Includere singoli e EP quando si scaricano gli album di un artista ('0'-No,'1'-Sì):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Aggiungere ID prima del nome della cartella per l'album ('0'-No,'1'-Sì):"
    CHANGE_SAVE_COVERS = "Salve copertine ('0'-No,'1'-Sì):"
    CHANGE_LANGUAGE = "Selezionare lingua"
    CHANGE_ALBUM_FOLDER_FORMAT = "Album folder format('0' not modify):"
    CHANGE_TRACK_FILE_FORMAT = "Track file format('0' not modify):"
    CHANGE_SHOW_PROGRESS = "Show progress('0'-No,'1'-Yes):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Save AlbumInfo.txt('0'-No,'1'-Yes):"
    CHANGE_ADD_LYRICS = "Add lyrics('0'-No,'1'-Yes):"
    CHANGE_LYRICS_SERVER_PROXY = "Lyrics server proxy('0' not modify):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Starting login process..."
    AUTH_LOGIN_CODE = "Your login code is {}"
    AUTH_NEXT_STEP = "Go to {} within the next {} to complete setup."
    AUTH_WAITING = "Waiting for authorization..."
    AUTH_TIMEOUT = "Operation timed out."

    MSG_VALID_ACCESSTOKEN = "AccessToken good for {}."
    MSG_INVAILD_ACCESSTOKEN = "Expired AccessToken. Attempting to refresh it."
    MSG_PATH_ERR = "Percorso errato!"
    MSG_INPUT_ERR = "Inserimento errato!"

    MODEL_ALBUM_PROPERTY = "PROPRIETÀ-ALBUM"
    MODEL_TRACK_PROPERTY = "PROPRIETÀ-TRACCIA"
    MODEL_VIDEO_PROPERTY = "PROPRIETÀ-VIDEO"
    MODEL_ARTIST_PROPERTY = "PROPRIETÀ-ARTISTA"
    MODEL_PLAYLIST_PROPERTY = "PROPRIETÀ-PLAYLIST"

    MODEL_TITLE = 'Titolo'
    MODEL_TRACK_NUMBER = 'Numero Traccia'
    MODEL_VIDEO_NUMBER = 'Numero Video'
    MODEL_RELEASE_DATE = 'Data uscita'
    MODEL_VERSION = 'Versione'
    MODEL_EXPLICIT = 'Contenuto Esplicito'
    MODEL_ALBUM = 'Album'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Nome'
    MODEL_TYPE = 'Tipo'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   chinese.py
@Time    :   2020/08/19
@Author  :   Yaronzz
@Version :   1.0
@Contact :   yaronhuang@foxmail.com
@Desc    :   
'''


class LangChinese(object):
    SETTING = "设置"
    VALUE = "值"
    SETTING_DOWNLOAD_PATH = "下载目录"
    SETTING_ONLY_M4A = "转换mp4为m4a"
    SETTING_ADD_EXPLICIT_TAG = "文件名添加脏话标签Explicit"
    SETTING_ADD_HYPHEN = "文件名用'-'代替空格"
    SETTING_ADD_YEAR = "专辑文件夹添加年代标签"
    SETTING_USE_TRACK_NUM = "歌曲名称添加序号"
    SETTING_AUDIO_QUALITY = "歌曲质量"
    SETTING_VIDEO_QUALITY = "视频质量"
    SETTING_CHECK_EXIST = "是否跳过已下载的文件"
    SETTING_ARTIST_BEFORE_TITLE = "文件名前添加歌手名"
    SETTING_ALBUMID_BEFORE_FOLDER = "专辑文件夹添加专辑ID"
    SETTING_INCLUDE_EP = "下载歌手专辑时包含其EP单曲"
    SETTING_SAVE_COVERS = "保存封面"
    SETTING_LANGUAGE = "语言"
    SETTING_USE_PLAYLIST_FOLDER = "将歌单下载到歌单目录"
    SETTING_MULITHREAD_DOWNLOAD = "多线程下载"
    SETTING_ALBUM_FOLDER_FORMAT = "专辑目录格式"
    SETTING_TRACK_FILE_FORMAT = "歌曲文件名格式"
    SETTING_SHOW_PROGRESS = "显示进度条"
    SETTING_SHOW_TRACKIFNO = "显示歌曲信息"
    SETTING_SAVE_ALBUMINFO = "保存AlbumInfo.txt"
    SETTING_ADD_LYRICS = "添加歌词"
    SETTING_LYRICS_SERVER_PROXY = "歌词服务器代理"
    SETTING_PATH = "Settings path"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey支持"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "选项"
    FUNCTION = "功能"
    CHOICE_ENTER = "输入"
    CHOICE_ENTER_URLID = "输入 'Url或ID':"
    CHOICE_EXIT = "退出"
    CHOICE_LOGIN = "Check AccessToken"
    CHOICE_SETTINGS = "配置"
    CHOICE_SET_ACCESS_TOKEN = "设置AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "通过链接或ID下载"
    CHOICE_LOGOUT = "注销"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[错误]"
    PRINT_INFO = "[提示]"
    PRINT_SUCCESS = "[成功]"

    PRINT_ENTER_CHOICE = "输入选项:"
    PRINT_LATEST_VERSION = "最新版本:"
    # PRINT_USERNAME = "用户:"
    # PRINT_PASSWORD = "密码:"

    CHANGE_START_SETTINGS = "开始设置('0'-返回,'1'-是):"
    CHANGE_DOWNLOAD_PATH = "下载路径('0' 不修改):"
    CHANGE_AUDIO_QUALITY = "音频质量('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "视频质量(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "将Mp4格式的音频转为M4a('0'-不,'1'-是):"
    CHANGE_ADD_EXPLICIT_TAG = "歌名后添加脏话标签('0'-不,'1'-是):"
    CHANGE_ADD_HYPHEN = "文件名中用'-'代替空格('0'-不,'1'-是):"
    CHANGE_ADD_YEAR = "专辑目录前添加年代标签('0'-不,'1'-是):"
    CHANGE_USE_TRACK_NUM = "文件名前添加序号('0'-不,'1'-是):"
    CHANGE_CHECK_EXIST = "下载前检查是否有已下载的文件('0'-不,'1'-是):"
    CHANGE_ARTIST_BEFORE_TITLE = "文件名前添加歌手名称('0'-不,'1'-是):"
    CHANGE_INCLUDE_EP = "下载歌手专辑时包含其EP单曲('0'-不,'1'-是):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "专辑目录前添加ID('0'-不,'1'-是):"
    CHANGE_SAVE_COVERS = "保存封面('0'-不,'1'-是):"
    CHANGE_LANGUAGE = "选择语言"
    CHANGE_ALBUM_FOLDER_FORMAT = "专辑目录格式('0' 不修改):"
    CHANGE_TRACK_FILE_FORMAT = "歌曲文件名格式('0' 不修改):"
    CHANGE_SHOW_PROGRESS = "显示进度条('0'-不,'1'-是):"
    CHANGE_SHOW_TRACKINFO = "显示歌曲信息('0'-否,'1'-是):"
    CHANGE_SAVE_ALBUM_INFO = "保存AlbumInfo.txt('0'-否,'1'-是):"
    CHANGE_ADD_LYRICS = "添加歌词('0'-否,'1'-是):"
    CHANGE_LYRICS_SERVER_PROXY = "歌词服务器代理('0' 不修改):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-否,'1'-是):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "开始启动登录..."
    AUTH_LOGIN_CODE = "你的登录码为: {}"
    AUTH_NEXT_STEP = "请打开 {} 并在 {} 之内完成操作."
    AUTH_WAITING = "等待登录验证..."
    AUTH_TIMEOUT = "操作超时."

    MSG_VALID_ACCESSTOKEN = "AccessToken保质期为 {}."
    MSG_INVAILD_ACCESSTOKEN = "AccessToken失效. 正在尝试更新它."
    MSG_PATH_ERR = "路径错误!"
    MSG_INPUT_ERR = "输入错误!"

    MODEL_ALBUM_PROPERTY = "专辑信息"
    MODEL_TRACK_PROPERTY = "歌曲信息"
    MODEL_VIDEO_PROPERTY = "视频信息"
    MODEL_ARTIST_PROPERTY = "歌手信息"
    MODEL_PLAYLIST_PROPERTY = "歌单信息"

    MODEL_TITLE = '标题'
    MODEL_TRACK_NUMBER = '歌曲数量'
    MODEL_VIDEO_NUMBER = '视频数量'
    MODEL_RELEASE_DATE = '发布时间'
    MODEL_VERSION = '版本'
    MODEL_EXPLICIT = '脏话标志'
    MODEL_ALBUM = '专辑'
    MODEL_ID = 'ID'
    MODEL_NAME = '名称'
    MODEL_TYPE = '类型'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   korean.py
@Time    :   2021/11/24
@Author  :   jee019
@Version :   1.1
@Contact :   qwer010910@gmail.com
@Desc    :   
'''


class LangKorean(object):
    SETTING = "설정"
    VALUE = "값"
    SETTING_DOWNLOAD_PATH = "다운로드 경로"
    SETTING_ONLY_M4A = "mp4를 m4a로 변환"
    SETTING_ADD_EXPLICIT_TAG = "explicit 태그 추가"
    SETTING_ADD_HYPHEN = "하이픈 추가"
    SETTING_ADD_YEAR = "앨범 폴더 앞에 연도 추가"
    SETTING_USE_TRACK_NUM = "사용자 트랙 번호 추가"
    SETTING_AUDIO_QUALITY = "음질"
    SETTING_VIDEO_QUALITY = "영상 화질"
    SETTING_CHECK_EXIST = "존재 유무 확인"
    SETTING_ARTIST_BEFORE_TITLE = "트랙 제목 앞 아티스트 이름"
    SETTING_ALBUMID_BEFORE_FOLDER = "앨범 폴더 앞 ID"
    SETTING_INCLUDE_EP = "싱글 및 EP 포함"
    SETTING_SAVE_COVERS = "커버 저장"
    SETTING_LANGUAGE = "언어"
    SETTING_USE_PLAYLIST_FOLDER = "재생목록 폴더 사용"
    SETTING_MULITHREAD_DOWNLOAD = "다중 스레드 다운로드"
    SETTING_ALBUM_FOLDER_FORMAT = "앨범 폴더 형식"
    SETTING_TRACK_FILE_FORMAT = "트랙 파일 형식"
    SETTING_SHOW_PROGRESS = "진행 상태 표시"
    SETTING_SHOW_TRACKIFNO = "트랙 정보 표시"
    SETTING_SAVE_ALBUMINFO = "AlbumInfo.txt 저장"
    SETTING_ADD_LYRICS = "가사 추가"
    SETTING_LYRICS_SERVER_PROXY = "가사 서버 프록시"
    SETTINGS_ADD_LRC_FILE = "timed 가사 저장 (.lrc 파일)"
    SETTING_PATH = "설정 경로"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "선택"
    FUNCTION = "기능"
    CHOICE_ENTER = "엔터"
    CHOICE_ENTER_URLID = "'Url/ID' 입력:"
    CHOICE_EXIT = "종료"
    CHOICE_LOGIN = "액세스 토큰 확인"
    CHOICE_SETTINGS = "설정"
    CHOICE_SET_ACCESS_TOKEN = "액세스 토큰 설정"
    CHOICE_DOWNLOAD_BY_URL = "Url 또는 id로 다운로드"
    CHOICE_LOGOUT = "로그아웃"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[에러]"
    PRINT_INFO = "[정보]"
    PRINT_SUCCESS = "[성공]"

    PRINT_ENTER_CHOICE = "선택 입력:"
    PRINT_LATEST_VERSION = "최신 버전:"
    # PRINT_USERNAME = "유저 이름:"
    # PRINT_PASSWORD = "비밀번호:"

    CHANGE_START_SETTINGS = "설정 시작('0'-뒤로가기,'1'-예):"
    CHANGE_DOWNLOAD_PATH = "다운로드 경로('0'-변경 안 함):"
    CHANGE_AUDIO_QUALITY = "음질('0'-보통,'1'-높음,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "영상 화질(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "mp4를 m4a로 변환('0'-아니요,'1'-예):"
    CHANGE_ADD_EXPLICIT_TAG = "파일 이름에 explicit 태그 추가('0'-아니요,'1'-예):"
    CHANGE_ADD_HYPHEN = "파일 이름에 공백 대신 하이픈 사용('0'-아니요,'1'-예):"
    CHANGE_ADD_YEAR = "앨범 폴더 이름에 연도 추가('0'-아니요,'1'-예):"
    CHANGE_USE_TRACK_NUM = "파일 이름 앞에 트랙 번호 추가('0'-아니요,'1'-예):"
    CHANGE_CHECK_EXIST = "다운로드 트랙 전에 존재하는 파일 확인('0'-아니요,'1'-예):"
    CHANGE_ARTIST_BEFORE_TITLE = "트랙 제목 앞에 아티스트 이름 추가('0'-아니요,'1'-예):"
    CHANGE_INCLUDE_EP = "아티스트 앨범 다운로드시 싱글 및 EP 포함('0'-아니요,'1'-예):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "앨범 폴더 앞에 ID 추가('0'-아니요,'1'-예):"
    CHANGE_SAVE_COVERS = "커버 저장('0'-아니요,'1'-예):"
    CHANGE_LANGUAGE = "언어 선택"
    CHANGE_ALBUM_FOLDER_FORMAT = "앨범 폴더 형식('0'-변경 안 함,'default'-기본 설정):"
    CHANGE_TRACK_FILE_FORMAT = "트랙 파일 형식('0'-변경 안 함,'default'-기본 설정):"
    CHANGE_SHOW_PROGRESS = "진행 상태 표시('0'-아니요,'1'-예):"
    CHANGE_SHOW_TRACKINFO = "트랙 정보 표시('0'-아니요,'1'-예):"
    CHANGE_SAVE_ALBUM_INFO = "AlbumInfo.txt 저장('0'-아니요,'1'-예):"
    CHANGE_ADD_LYRICS = "가사 추가('0'-아니요,'1'-예):"
    CHANGE_LYRICS_SERVER_PROXY = "가사 서버 프록시('0'-변경 안 함):"
    CHANGE_ADD_LRC_FILE = "timed 가사 .lrc 파일 저장 ('0'-아니요,'1'-예):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "로그인 중..."
    AUTH_LOGIN_CODE = "로그인 코드는 다음과 같습니다. {}"
    AUTH_NEXT_STEP = "설치를 완료하려면 {}로 이동하십시오. 다음 {} 내에 있습니다."
    AUTH_WAITING = "승인 대기 중..."
    AUTH_TIMEOUT = "작업 시간 초과"

    MSG_VALID_ACCESSTOKEN = "{}에 대해 액세스 토큰이 유효합니다."
    MSG_INVAILD_ACCESSTOKEN = "만료된 액세스 토큰입니다. 새로 고침 중입니다."
    MSG_PATH_ERR = "경로 오류!"
    MSG_INPUT_ERR = "입력 오류!"

    MODEL_ALBUM_PROPERTY = "앨범-정보"
    MODEL_TRACK_PROPERTY = "트랙-정보"
    MODEL_VIDEO_PROPERTY = "영상-정보"
    MODEL_ARTIST_PROPERTY = "아티스트-정보"
    MODEL_PLAYLIST_PROPERTY = "재생목록-정보"

    MODEL_TITLE = '제목'
    MODEL_TRACK_NUMBER = '트랙 넘버'
    MODEL_VIDEO_NUMBER = '영상 넘버'
    MODEL_RELEASE_DATE = '발매일'
    MODEL_VERSION = '버전'
    MODEL_EXPLICIT = 'Explicit'
    MODEL_ALBUM = '앨범'
    MODEL_ID = '아이디'
    MODEL_NAME = '이름'
    MODEL_TYPE = '형식'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   hungarian.py
@Time    :   2021/06/20
@Author  :   Shanahan
@Version :   1.0
@Contact :   
@Desc    :   
'''


class LangHungarian(object):
    SETTING = "BEÁLLÍTÁSOK"
    VALUE = "ÉRTÉK"
    SETTING_DOWNLOAD_PATH = "Letöltési útvonal"
    SETTING_ONLY_M4A = "mp4 konvertálása m4a-ra"
    SETTING_ADD_EXPLICIT_TAG = "Explicit tag hozzáadása"
    SETTING_ADD_HYPHEN = "Kötőjel hozzáadása"
    SETTING_ADD_YEAR = "Év hozzáadása az album-mappa előtt"
    SETTING_USE_TRACK_NUM = "Add user track number"
    SETTING_AUDIO_QUALITY = "Audió minősége"
    SETTING_VIDEO_QUALITY = "Videó minősége"
    SETTING_CHECK_EXIST = "Ellenőrizze, hogy létezik-e"
    SETTING_ARTIST_BEFORE_TITLE = "Előadó neve a szám címe előtt"
    SETTING_ALBUMID_BEFORE_FOLDER = "Azonosító (ID) az album-mappa előtt"
    SETTING_INCLUDE_EP = "Tartalmazza a single&ep"
    SETTING_SAVE_COVERS = "Borító mentése"
    SETTING_LANGUAGE = "Nyelv"
    SETTING_USE_PLAYLIST_FOLDER = "Lejátszási lista mappa használata"
    SETTING_MULITHREAD_DOWNLOAD = "Többszálú letöltés"
    SETTING_ALBUM_FOLDER_FORMAT = "Album mappa formátum"
    SETTING_TRACK_FILE_FORMAT = "Track fájlformátum"
    SETTING_SHOW_PROGRESS = "Haladás megjelenítése"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "AlbumInfo.txt mentése"
    SETTING_ADD_LYRICS = "Dalszöveg hozzáadása"
    SETTING_LYRICS_SERVER_PROXY = "Dalszöveg kiszolgáló proxy"
    SETTING_PATH = "Beállítások elérési útvonala"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "VÁLASZTÁS"
    FUNCTION = "FUNKCIÓ"
    CHOICE_ENTER = "Írja be a"
    CHOICE_ENTER_URLID = "Adja meg az 'Url/ID'-t:"
    CHOICE_EXIT = "Kilépés"
    CHOICE_LOGIN = "AccessToken ellenőrzése"
    CHOICE_SETTINGS = "Beállítások"
    CHOICE_SET_ACCESS_TOKEN = "AccessToken beállítása"
    CHOICE_DOWNLOAD_BY_URL = "Letöltés URL vagy ID alapján"
    CHOICE_LOGOUT = "Kijelentkezés"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[HIBA]"
    PRINT_INFO = "[INFÓ]"
    PRINT_SUCCESS = "[SIKERES]"

    PRINT_ENTER_CHOICE = "Válasszon:"
    PRINT_LATEST_VERSION = "Legújabb verzió:"
    # PRINT_USERNAME = "felhasználónév:"
    # PRINT_PASSWORD = "jelszó

    CHANGE_START_SETTINGS = "Beállítások indítása('0'- Vissza, '1'-Igen):"
    CHANGE_DOWNLOAD_PATH = "Letöltési útvonal('0' nincs módosítás):"
    CHANGE_AUDIO_QUALITY = "Audió minőség('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "Videó minőség(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "mp4 átalakítása m4a-ra('0'-Nem,'1'-Igen):"
    CHANGE_ADD_EXPLICIT_TAG = "Explicit tag hozzáadása a fájlnevekhez('0'-Nem,'1'-Igen):"
    CHANGE_ADD_HYPHEN = "Kötőjel használata szóköz helyett a fájlnevekben('0'-Nem,'1'-Igen):"
    CHANGE_ADD_YEAR = "Évszám hozzáadása az album mappanevekhez('0'-Nem,'1'-Igen):"
    CHANGE_USE_TRACK_NUM = "Track szám hozzáadása a fájlnevek előtt('0'-Nem,'1'-Igen):"
    CHANGE_CHECK_EXIST = "Létező fájl ellenőrzése letöltés előtt('0'-Nem,'1'-Igen):"
    CHANGE_ARTIST_BEFORE_TITLE = "Előadó hozzáadása a szám címe előtt('0'-Nem,'1'-Igen):"
    CHANGE_INCLUDE_EP = "A kislemezek és EP-k letöltése('0'-nem, '1'-igen):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Azonosító (ID) az album mappa előtt('0'-Nem,'1'-Igen):"
    CHANGE_SAVE_COVERS = "Borító mentése('0'-nem, '1'-igen):"
    CHANGE_LANGUAGE = "Nyelv kiválasztása"
    CHANGE_ALBUM_FOLDER_FORMAT = "Album mappa formátum('0' nincs módosítás,'default' az alapértelmezett beállításhoz):"
    CHANGE_TRACK_FILE_FORMAT = "Track fájl neve('0' nincs módosítás,'default' az alapértelmezett beállításhoz):"
    CHANGE_SHOW_PROGRESS = "Haladás megjelenítése('0'-nem, '1'-igen):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "AlbumInfo.txt mentése('0'-nem, '1'-igen):"
    CHANGE_ADD_LYRICS = "Dalszöveg hozzáadása('0'-nem,'1'-igen):"
    CHANGE_LYRICS_SERVER_PROXY = "Dalszöveg kiszolgáló prox('0' nincs módosítás):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Bejelentkezési folyamat elindítása..."
    AUTH_LOGIN_CODE = "A bejelentkezési kódod {}"
    AUTH_NEXT_STEP = "Menj a {} a következő {} a beállítás befejezéséhez."
    AUTH_WAITING = "Engedélyre várva..."
    AUTH_TIMEOUT = "A művelet leállt."

    MSG_VALID_ACCESSTOKEN = "AccessToken érvényessége {}."
    MSG_INVAILD_ACCESSTOKEN = "Lejárt AccessToken. Megpróbálom frissíteni."
    MSG_PATH_ERR = "Az útvonal hibás!"
    MSG_INPUT_ERR = "Beviteli hiba!"

    MODEL_ALBUM_PROPERTY = "ALBUM-TULAJDONSÁGOK"
    MODEL_TRACK_PROPERTY = "TRACK-TULAJDONSÁGOK"
    MODEL_VIDEO_PROPERTY = "VIDEO-TULAJDONSÁGOK"
    MODEL_ARTIST_PROPERTY = "ELŐADÓ-TULAJDONSÁGOK"
    MODEL_PLAYLIST_PROPERTY = "LEJÁTSZÁSI LISTA-TULAJDONSÁGOK"

    MODEL_TITLE = 'Cím'
    MODEL_TRACK_NUMBER = 'Track száma'
    MODEL_VIDEO_NUMBER = 'Videó száma'
    MODEL_RELEASE_DATE = 'Megjelenés dátuma'
    MODEL_VERSION = 'Verzió'
    MODEL_EXPLICIT = 'Explicit'
    MODEL_ALBUM = 'Album'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Név'
    MODEL_TYPE = 'Típus'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :  apiKey.py
@Date    :  2021/11/30
@Author  :  Yaronzz
@Version :  1.0
@Contact :  yaronhuang@foxmail.com
@Desc    :
"""

__API_KEYS__ = [
    #api key from @Fokka-Engineering
    #https://github.com/Fokka-Engineering/libopenTIDAL/blob/655528e26e4f3ee2c426c06ea5b8440cf27abc4a/README.md#example
    {
        'platform': 'Fire TV',
        'formats': 'Normal/High/HiFi(No Master)',
        'clientId': 'OmDtrzFgyVVL6uW56OnFA2COiabqm',
        'clientSecret': 'zxen1r3pO0hgtOC7j6twMo9UAqngGrmRiWpV7QC1zJ8=',
        'valid': 'False',
    },
    #api key from @Dniel97
    #https://github.com/Dniel97/RedSea/blob/4ba02b88cee33aeb735725cb854be6c66ff372d4/config/settings.example.py#L68
    {
        'platform': 'Fire TV',
        'formats': 'Master-Only(Else Error)',
        'clientId': '7m7Ap0JC9j1cOM3n',
        'clientSecret': 'vRAdA108tlvkJpTsGZS8rGZ7xTlbJ0qaZ2K9saEzsgY=',
        'valid': 'True',
    },
    {
        'platform': 'Android TV',
        'formats': 'Normal/High/HiFi(No Master)',
        'clientId': 'Pzd0ExNVHkyZLiYN',
        'clientSecret': 'W7X6UvBaho+XOi1MUeCX6ewv2zTdSOV3Y7qC3p3675I=',
        'valid': 'False',
    },
    #api key from @morguldir 
    #https://github.com/morguldir/python-tidal/commit/50f1afcd2079efb2b4cf694ef5a7d67fdf619d09
    {
        'platform': 'TV',
        'formats': 'Normal/High/HiFi/Master',
        'clientId': '8SEZWa4J1NVC5U5Y',
        'clientSecret': 'owUYDkxddz+9FpvGX24DlxECNtFEMBxipU0lBfrbq60=',
        'valid': 'True',
    },
]

__ERROR_KEY__ = {
                    'platform': 'None',
                    'formats': '',
                    'clientId': '',
                    'clientSecret': '',
                    'valid': 'False',
                },


def getNum():
    return len(__API_KEYS__)


def getItem(index: int):
    if index < 0 or index >= len(__API_KEYS__):
        return __ERROR_KEY__
    return __API_KEYS__[index]


def getItems():
    return __API_KEYS__


def getLimitIndexs():
    array = []
    for i in range(len(__API_KEYS__)):
        array.append(str(i))
    return array



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   download.py
@Time    :   2020/11/08
@Author  :   Yaronzz
@Version :   1.0
@Contact :   yaronhuang@foxmail.com
@Desc    :   
'''
import requests
import logging
import os
import datetime

import aigpy
import lyricsgenius
from tidal_dl.decryption import decrypt_file
from tidal_dl.decryption import decrypt_security_token
from tidal_dl.enums import Type, AudioQuality
from tidal_dl.model import Track, Video, Lyrics, Mix
from tidal_dl.printf import Printf
from tidal_dl.settings import Settings
from tidal_dl.tidal import TidalAPI
from tidal_dl.util import convert, downloadTrack, downloadVideo, encrypted, getVideoPath, getTrackPath, getAlbumPath, API


def __loadAPI__(user):
    API.key.accessToken = user.accessToken
    API.key.userId = user.userid
    API.key.countryCode = user.countryCode


def __downloadCover__(conf, album):
    if album == None:
        return
    path = getAlbumPath(conf, album) + '/cover.jpg'
    url = API.getCoverUrl(album.cover, "1280", "1280")
    if url is not None:
        aigpy.net.downloadFile(url, path)


def __saveAlbumInfo__(conf, album, tracks):
    if album == None:
        return
    path = getAlbumPath(conf, album) + '/AlbumInfo.txt'

    infos = ""
    infos += "[ID]          %s\n" % (str(album.id))
    infos += "[Title]       %s\n" % (str(album.title))
    infos += "[Artists]     %s\n" % (str(album.artist.name))
    infos += "[ReleaseDate] %s\n" % (str(album.releaseDate))
    infos += "[SongNum]     %s\n" % (str(album.numberOfTracks))
    infos += "[Duration]    %s\n" % (str(album.duration))
    infos += '\n'

    i = 0
    while True:
        if i >= int(album.numberOfVolumes):
            break
        i = i + 1
        infos += "===========CD %d=============\n" % i
        for item in tracks:
            if item.volumeNumber != i:
                continue
            infos += '{:<8}'.format("[%d]" % item.trackNumber)
            infos += "%s\n" % item.title
    aigpy.file.write(path, infos, "w+")


def __album__(conf, obj):
    Printf.album(obj)
    msg, tracks, videos = API.getItems(obj.id, Type.Album)
    if not aigpy.string.isNull(msg):
        Printf.err(msg)
        return
    if conf.saveAlbumInfo:
        __saveAlbumInfo__(conf, obj, tracks)
    if conf.saveCovers:
        __downloadCover__(conf, obj)
    for item in tracks:
        downloadTrack(item, obj)
    for item in videos:
        downloadVideo(item, obj)


def __track__(conf, obj):
    msg, album = API.getAlbum(obj.album.id)
    if conf.saveCovers:
        __downloadCover__(conf, album)
    downloadTrack(obj, album)


def __video__(conf, obj):
    # Printf.video(obj)
    downloadVideo(obj, obj.album)


def __artist__(conf, obj):
    msg, albums = API.getArtistAlbums(obj.id, conf.includeEP)
    Printf.artist(obj, len(albums))
    if not aigpy.string.isNull(msg):
        Printf.err(msg)
        return
    for item in albums:
        __album__(conf, item)


def __playlist__(conf, obj):
    Printf.playlist(obj)
    msg, tracks, videos = API.getItems(obj.uuid, Type.Playlist)
    if not aigpy.string.isNull(msg):
        Printf.err(msg)
        return

    for index, item in enumerate(tracks):
        mag, album = API.getAlbum(item.album.id)
        item.trackNumberOnPlaylist = index + 1
        downloadTrack(item, album, obj)
        if conf.saveCovers and not conf.usePlaylistFolder:
            __downloadCover__(conf, album)
    for item in videos:
        downloadVideo(item, None)
        

def __mix__(conf, obj: Mix):
    Printf.mix(obj)
    for index, item in enumerate(obj.tracks):
        mag, album = API.getAlbum(item.album.id)
        item.trackNumberOnPlaylist = index + 1
        downloadTrack(item, album)
        if conf.saveCovers and not conf.usePlaylistFolder:
            __downloadCover__(conf, album)
    for item in obj.videos:
        downloadVideo(item, None)


def file(user, conf, string):
    txt = aigpy.file.getContent(string)
    if aigpy.string.isNull(txt):
        Printf.err("Nothing can read!")
        return
    array = txt.split('\n')
    for item in array:
        if aigpy.string.isNull(item):
            continue
        if item[0] == '#':
            continue
        if item[0] == '[':
            continue
        start(user, conf, item)


def start(user, conf, string):
    __loadAPI__(user)
    if aigpy.string.isNull(string):
        Printf.err('Please enter something.')
        return

    strings = string.split(" ")
    for item in strings:
        if aigpy.string.isNull(item):
            continue
        if os.path.exists(item):
            file(user, conf, item)
            return

        msg, etype, obj = API.getByString(item)
        if etype == Type.Null or not aigpy.string.isNull(msg):
            Printf.err(msg + " [" + item + "]")
            return

        if etype == Type.Album:
            __album__(conf, obj)
        if etype == Type.Track:
            __track__(conf, obj)
        if etype == Type.Video:
            __video__(conf, obj)
        if etype == Type.Artist:
            __artist__(conf, obj)
        if etype == Type.Playlist:
            __playlist__(conf, obj)
        if etype == Type.Mix:
            __mix__(conf, obj)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   tidal.py
@Time    :   2019/02/27
@Author  :   Yaronzz
@VERSION :   2.0
@Contact :   yaronhuang@foxmail.com
@Desc    :   tidal api
'''
import base64
import json
import logging

import aigpy.stringHelper as stringHelper
import requests
from aigpy.modelHelper import dictToModel
from aigpy.stringHelper import isNull
from requests.packages import urllib3
from tidal_dl.enums import Type, AudioQuality, VideoQuality
from tidal_dl.model import Album, Track, Video, Artist, Playlist, StreamUrl, VideoStreamUrl, SearchResult, Lyrics, Mix
import tidal_dl.apiKey as apiKey

__VERSION__ = '1.9.1'
__URL_PRE__ = 'https://api.tidalhifi.com/v1/'
__AUTH_URL__ = 'https://auth.tidal.com/v1/oauth2'
__API_KEY__ = {'clientId': '7m7Ap0JC9j1cOM3n',
               'clientSecret': 'vRAdA108tlvkJpTsGZS8rGZ7xTlbJ0qaZ2K9saEzsgY='}

# SSL Warnings
urllib3.disable_warnings()
# add retry number
requests.adapters.DEFAULT_RETRIES = 5


class LoginKey(object):
    def __init__(self):
        self.deviceCode = None
        self.userCode = None
        self.verificationUrl = None
        self.authCheckTimeout = None
        self.authCheckInterval = None
        self.userId = None
        self.countryCode = None
        self.accessToken = None
        self.refreshToken = None
        self.expiresIn = None


class __StreamRespond__(object):
    trackid = None
    videoid = None
    streamType = None
    assetPresentation = None
    audioMode = None
    audioQuality = None
    videoQuality = None
    manifestMimeType = None
    manifest = None


class TidalAPI(object):
    def __init__(self):
        self.apiKey = __API_KEY__
        self.key = LoginKey()
        self.__debugVar = 0

    def __toJson__(self, string: str):
        try:
            json_object = json.loads(string)
        except:
            return None
        return json_object

    def __get__(self, path, params={}, retry=3, urlpre=__URL_PRE__):
        # deprecate the sessionId
        # header = {'X-Tidal-SessionId': self.key.sessionId}T
        header = {}
        if not isNull(self.key.accessToken):
            header = {'authorization': 'Bearer {}'.format(self.key.accessToken)}
        params['countryCode'] = self.key.countryCode

        result = None
        respond = None
        for index in range(0, retry):
            try:
                respond = requests.get(urlpre + path, headers=header, params=params)
                result = self.__toJson__(respond.text)
                break
            except:
                continue

        if result is None:
            return "Get operation err!" + respond.text, None
        if 'status' in result:
            if 'userMessage' in result and result['userMessage'] is not None:
                return result['userMessage'], None
            else:
                logging.error("[Get operation err] path=" + path + ". respon=" + respond.text)
                return "Get operation err!", None
        return None, result

    def __getItems__(self, path, params={}, retry=3):
        params['limit'] = 50
        params['offset'] = 0
        total = 0
        ret = []
        while True:
            msg, data = self.__get__(path, params, retry)
            if msg is not None:
                return msg, None
            
            if 'totalNumberOfItems'in data:
                total = data['totalNumberOfItems']
            if total > 0 and total <= len(ret):
                return None, ret
            
            num = 0
            for item in data["items"]:
                num += 1
                ret.append(item)
            if num < 50:
                break
            params['offset'] += num
        return None, ret

    def __getQualityString__(self, quality: AudioQuality):
        if quality == AudioQuality.Normal:
            return "LOW"
        if quality == AudioQuality.High:
            return "HIGH"
        if quality == AudioQuality.HiFi:
            return "LOSSLESS"
        return "HI_RES"

    def __getResolutionList__(self, url):
        ret = []
        txt = requests.get(url).text
        # array = txt.split("#EXT-X-STREAM-INF")
        array = txt.split("#")
        for item in array:
            if "RESOLUTION=" not in item:
                continue
            if "EXT-X-STREAM-INF:" not in item:
                continue
            stream = VideoStreamUrl()
            stream.codec = stringHelper.getSub(item, "CODECS=\"", "\"")
            stream.m3u8Url = "http" + stringHelper.getSubOnlyStart(item, "http").strip()
            stream.resolution = stringHelper.getSub(item, "RESOLUTION=", "http").strip()
            stream.resolution = stream.resolution.split(',')[0]
            stream.resolutions = stream.resolution.split("x")
            ret.append(stream)
        return ret

    def __post__(self, url, data, auth=None):
        retry = 3
        while retry > 0:
            try:
                result = requests.post(url, data=data, auth=auth, verify=False).json()
            except (
                    requests.ConnectionError,
                    requests.exceptions.ReadTimeout,
                    requests.exceptions.Timeout,
                    requests.exceptions.ConnectTimeout,
            ) as e:
                retry -= 1
                if retry <= 0:
                    return e, None
                continue
            return None, result

    def getDeviceCode(self):
        data = {
            'client_id': self.apiKey['clientId'],
            'scope': 'r_usr+w_usr+w_sub'
        }
        e, result = self.__post__(__AUTH_URL__ + '/device_authorization', data)
        if e is not None:
            return str(e), False

        if 'status' in result and result['status'] != 200:
            return "Device authorization failed. Please try again.", False

        self.key.deviceCode = result['deviceCode']
        self.key.userCode = result['userCode']
        self.key.verificationUrl = result['verificationUri']
        self.key.authCheckTimeout = result['expiresIn']
        self.key.authCheckInterval = result['interval']
        return None, True

    def checkAuthStatus(self):
        data = {
            'client_id': self.apiKey['clientId'],
            'device_code': self.key.deviceCode,
            'grant_type': 'urn:ietf:params:oauth:grant-type:device_code',
            'scope': 'r_usr+w_usr+w_sub'
        }
        e, result = self.__post__(__AUTH_URL__ + '/token', data, (self.apiKey['clientId'], self.apiKey['clientSecret']))
        if e is not None:
            return str(e), False

        if 'status' in result and result['status'] != 200:
            if result['status'] == 400 and result['sub_status'] == 1002:
                return "pending", False
            else:
                return "Error while checking for authorization. Trying again...", False

        # if auth is successful:
        self.key.userId = result['user']['userId']
        self.key.countryCode = result['user']['countryCode']
        self.key.accessToken = result['access_token']
        self.key.refreshToken = result['refresh_token']
        self.key.expiresIn = result['expires_in']
        return None, True

    def verifyAccessToken(self, accessToken):
        header = {'authorization': 'Bearer {}'.format(accessToken)}
        result = requests.get('https://api.tidal.com/v1/sessions', headers=header).json()
        if 'status' in result and result['status'] != 200:
            return "Login failed!", False
        return None, True

    def refreshAccessToken(self, refreshToken):
        data = {
            'client_id': self.apiKey['clientId'],
            'refresh_token': refreshToken,
            'grant_type': 'refresh_token',
            'scope': 'r_usr+w_usr+w_sub'
        }

        e, result = self.__post__(__AUTH_URL__ + '/token', data, (self.apiKey['clientId'], self.apiKey['clientSecret']))
        if e is not None:
            return str(e), False

        # result = requests.post(__AUTH_URL__ + '/token', data=data, auth=(self.apiKey['clientId'], self.apiKey['clientSecret'])).json()
        if 'status' in result and result['status'] != 200:
            return "Refresh failed. Please log in again.", False

        # if auth is successful:
        self.key.userId = result['user']['userId']
        self.key.countryCode = result['user']['countryCode']
        self.key.accessToken = result['access_token']
        self.key.expiresIn = result['expires_in']
        return None, True

    def loginByAccessToken(self, accessToken, userid=None):
        header = {'authorization': 'Bearer {}'.format(accessToken)}
        result = requests.get('https://api.tidal.com/v1/sessions', headers=header).json()
        if 'status' in result and result['status'] != 200:
            return "Login failed!", False

        if not isNull(userid):
            if str(result['userId']) != str(userid):
                return "User mismatch! Please use your own accesstoken.", False

        self.key.userId = result['userId']
        self.key.countryCode = result['countryCode']
        self.key.accessToken = accessToken
        return None, True

    def getAlbum(self, id):
        msg, data = self.__get__('albums/' + str(id))
        return msg, dictToModel(data, Album())

    def getPlaylist(self, id):
        msg, data = self.__get__('playlists/' + str(id))
        return msg, dictToModel(data, Playlist())

    def getArtist(self, id):
        msg, data = self.__get__('artists/' + str(id))
        return msg, dictToModel(data, Artist())

    def getTrack(self, id):
        msg, data = self.__get__('tracks/' + str(id))
        return msg, dictToModel(data, Track())

    def getVideo(self, id):
        msg, data = self.__get__('videos/' + str(id))
        return msg, dictToModel(data, Video())
    
    def getMix(self, id):
        msg, tracks, videos = self.getItems(id, Type.Mix)
        if msg is not None:
            return msg, None
        mix = Mix()
        mix.id = id
        mix.tracks = tracks
        mix.videos = videos
        return None, mix
        
    def search(self, text: str, type: Type, offset: int, limit: int):
        typeStr = "ARTISTS,ALBUMS,TRACKS,VIDEOS,PLAYLISTS"
        if type == Type.Album:
            typeStr = "ALBUMS"
        if type == Type.Artist:
            typeStr = "ARTISTS"
        if type == Type.Track:
            typeStr = "TRACKS"
        if type == Type.Video:
            typeStr = "VIDEOS"
        if type == Type.Playlist:
            typeStr = "PLAYLISTS"

        params = {"query": text,
                  "offset": offset,
                  "limit": limit,
                  "types": typeStr}

        msg, data = self.__get__('search', params=params)
        return msg, dictToModel(data, SearchResult())

    def getLyrics(self, id):
        msg, data = self.__get__('tracks/' + str(id) + "/lyrics", urlpre='https://listen.tidal.com/v1/')
        return msg, dictToModel(data, Lyrics())

    def getItems(self, id, type: Type):
        if type == Type.Playlist:
            msg, data = self.__getItems__('playlists/' + str(id) + "/items")
        elif type == Type.Album:
            msg, data = self.__getItems__('albums/' + str(id) + "/items")
        elif type == Type.Mix:
            msg, data = self.__getItems__('mixes/' + str(id) + '/items')
        else:
            return "invalid Type!", None, None
        if msg is not None:
            return msg, None, None
        tracks = []
        videos = []
        for item in data:
            if item['type'] == 'track':
                tracks.append(dictToModel(item['item'], Track()))
            else:
                videos.append(dictToModel(item['item'], Video()))
        return msg, tracks, videos

    def getArtistAlbums(self, id, includeEP=False):
        albums = []
        msg, data = self.__getItems__('artists/' + str(id) + "/albums")
        if msg is not None:
            return msg, None
        for item in data:
            albums.append(dictToModel(item, Album()))
        if includeEP == False:
            return None, albums
        msg, data = self.__getItems__('artists/' + str(id) + "/albums", {"filter": "EPSANDSINGLES"})
        if msg is not None:
            return msg, None
        for item in data:
            albums.append(dictToModel(item, Album()))
        return None, albums

    def getStreamUrl(self, id, quality: AudioQuality):
        squality = self.__getQualityString__(quality)
        paras = {"audioquality": squality, "playbackmode": "STREAM", "assetpresentation": "FULL"}
        msg, data = self.__get__('tracks/' + str(id) + "/playbackinfopostpaywall", paras)
        if msg is not None:
            return msg, None
        resp = dictToModel(data, __StreamRespond__())

        if "vnd.tidal.bt" in resp.manifestMimeType:
            manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
            ret = StreamUrl()
            ret.trackid = resp.trackid
            ret.soundQuality = resp.audioQuality
            ret.codec = manifest['codecs']
            ret.encryptionKey = manifest['keyId'] if 'keyId' in manifest else ""
            ret.url = manifest['urls'][0]
            return "", ret
        return "Can't get the streamUrl, type is " + resp.manifestMimeType, None

    def getVideoStreamUrl(self, id, quality: VideoQuality):
        paras = {"videoquality": "HIGH", "playbackmode": "STREAM", "assetpresentation": "FULL"}
        msg, data = self.__get__('videos/' + str(id) + "/playbackinfopostpaywall", paras)
        if msg is not None:
            return msg, None
        resp = dictToModel(data, __StreamRespond__())

        if "vnd.tidal.emu" in resp.manifestMimeType:
            manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
            array = self.__getResolutionList__(manifest['urls'][0])
            icmp = int(quality.value)
            index = 0
            for item in array:
                if icmp <= int(item.resolutions[1]):
                    break
                index += 1
            if index >= len(array):
                index = len(array) - 1
            return "", array[index]
        return "Can't get the streamUrl, type is " + resp.manifestMimeType, None

    def getTrackContributors(self, id):
        msg, data = self.__get__('tracks/' + str(id) + "/contributors")
        return msg, data

    def getCoverUrl(self, sid, width="320", height="320"):
        if sid is None or sid == "":
            return None
        return "https://resources.tidal.com/images/" + sid.replace("-", "/") + "/" + width + "x" + height + ".jpg"
    
    def getCoverData(self, sid, width="320", height="320"):
        url = self.getCoverUrl(sid, width, height)
        try:
            respond = requests.get(url)
            return respond.content
        except:
            return ''

    def getArtistsName(self, artists=[]):
        array = []
        for item in artists:
            array.append(item.name)
        return " / ".join(array)

    def getFlag(self, data, type: Type, short=True, separator=" / "):
        master = False
        atmos = False
        explicit = False
        if type == Type.Album or type == Type.Track:
            if data.audioQuality == "HI_RES":
                master = True
            if type == Type.Album and "DOLBY_ATMOS" in data.audioModes:
                atmos = True
            if data.explicit is True:
                explicit = True
        if type == Type.Video:
            if data.explicit is True:
                explicit = True
        if not master and not atmos and not explicit:
            return ""
        array = []
        if master:
            array.append("M" if short else "Master")
        if atmos:
            array.append("A" if short else "Dolby Atmos")
        if explicit:
            array.append("E" if short else "Explicit")
        return separator.join(array)

    def parseUrl(self, url):
        etype = Type.Null
        sid = ""
        if "tidal.com" not in url:
            return etype, sid

        url = url.lower()
        if 'artist' in url:
            etype = Type.Artist
        if 'album' in url:
            etype = Type.Album
        if 'track' in url:
            etype = Type.Track
        if 'video' in url:
            etype = Type.Video
        if 'playlist' in url:
            etype = Type.Playlist
        if 'mix' in url:
            etype = Type.Mix

        if etype == Type.Null:
            return etype, sid

        sid = stringHelper.getSub(url, etype.name.lower() + '/', '/')
        return etype, sid

    def getByString(self, string):
        etype = Type.Null
        obj = None

        if isNull(string):
            return "Please enter something.", etype, obj
        etype, sid = self.parseUrl(string)
        if isNull(sid):
            sid = string

        if obj is None and (etype == Type.Null or etype == Type.Album):
            msg, obj = self.getAlbum(sid)
        if obj is None and (etype == Type.Null or etype == Type.Artist):
            msg, obj = self.getArtist(sid)
        if obj is None and (etype == Type.Null or etype == Type.Track):
            msg, obj = self.getTrack(sid)
        if obj is None and (etype == Type.Null or etype == Type.Video):
            msg, obj = self.getVideo(sid)
        if obj is None and (etype == Type.Null or etype == Type.Playlist):
            msg, obj = self.getPlaylist(sid)
        if obj is None and (etype == Type.Null or etype == Type.Mix):
            msg, obj = self.getMix(sid)

        if obj is None or etype != Type.Null:
            return msg, etype, obj
        if obj.__class__ == Album:
            etype = Type.Album
        if obj.__class__ == Artist:
            etype = Type.Artist
        if obj.__class__ == Track:
            etype = Type.Track
        if obj.__class__ == Video:
            etype = Type.Video
        if obj.__class__ == Playlist:
            etype = Type.Playlist
        if obj.__class__ == Mix:
            etype = Type.Mix
        return msg, etype, obj

    """
    def getToken(self):
        token1 = "MbjR4DLXz1ghC4rV"    
        token2 = "pl4Vc0hemlAXD0mN"    # only lossless
        try:
            msg = requests.get( "https://cdn.jsdelivr.net/gh/yaronzz/CDN@latest/app/tidal/tokens.json", timeout=(20.05, 27.05))
            tokens = json.loads(msg.text)
            token1 = tokens['token']
            token2 = tokens['token2']
        except Exception as e:
            pass
        return token1,token2
    """



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   russian.py
@Time    :   2020/11/29
@Author  :   sergey.seve-s
@Version :   1.0
@Contact :   
@Desc    :   
'''


class LangRussian(object):
    SETTING = "НАСТРОЙКА"
    VALUE = "УСТАНОВКА"
    SETTING_DOWNLOAD_PATH = "Место сохранения"
    SETTING_ONLY_M4A = "Сохранять mp4 как m4a"
    SETTING_ADD_EXPLICIT_TAG = "Добавить тег Нецензурно"
    SETTING_ADD_HYPHEN = "Добавить дефис"
    SETTING_ADD_YEAR = "Добавить год перед именем папки-альбома"
    SETTING_USE_TRACK_NUM = "Добавить номер трека"
    SETTING_AUDIO_QUALITY = "Качество аудио"
    SETTING_VIDEO_QUALITY = "Качество видео"
    SETTING_CHECK_EXIST = "Проверять наличие"
    SETTING_ARTIST_BEFORE_TITLE = "Исполнитель перед названием трека"
    SETTING_ALBUMID_BEFORE_FOLDER = "ID перед названием папки"
    SETTING_INCLUDE_EP = "Включить сингл и миньон"
    SETTING_SAVE_COVERS = "Добавлять обложку"
    SETTING_LANGUAGE = "Язык"
    SETTING_USE_PLAYLIST_FOLDER = "Плейлисты в отдельную папку"
    SETTING_MULITHREAD_DOWNLOAD = "Многопоточная загрузка"
    SETTING_ALBUM_FOLDER_FORMAT = "Маска имени альбома"
    SETTING_TRACK_FILE_FORMAT = "Маска имени трека"
    SETTING_SHOW_PROGRESS = "Показывать процесс загрузки"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Сохранять AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Добавлять текст песень"
    SETTING_LYRICS_SERVER_PROXY = "Прокси сервер для текстов песен"
    SETTING_PATH = "Путь для настроек"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "ВЫБРАТЬ"
    FUNCTION = "ФУНКЦИИ"
    CHOICE_ENTER = "Ввод"
    CHOICE_ENTER_URLID = "Ввод 'Url/ID':"
    CHOICE_EXIT = "Выход"
    CHOICE_LOGIN = "Проверить AccessToken"
    CHOICE_SETTINGS = "Настройки"
    CHOICE_SET_ACCESS_TOKEN = "Применить AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "Использовать ссылку для загрузки"
    CHOICE_LOGOUT = "Переподключение"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[ОШИБКА]"
    PRINT_INFO = "[СВЕДЕНИЯ]"
    PRINT_SUCCESS = "[ГОТОВО]"

    PRINT_ENTER_CHOICE = "Выбор функции:"
    PRINT_LATEST_VERSION = "Последняя версия:"
    # PRINT_USERNAME = "Имя:"
    # PRINT_PASSWORD = "Пароль:"

    CHANGE_START_SETTINGS = "Начальная настройка('0'-Отмена,'1'-Да):"
    CHANGE_DOWNLOAD_PATH = "Место сохранения('0'-Отмена):"
    CHANGE_AUDIO_QUALITY = "Качество аудио('0'-Стандарт,'1'-Высокое,'2'-HiFi,'3'-MQA):"
    CHANGE_VIDEO_QUALITY = "Качество видео(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Сохранять mp4 как m4a('0'-Нет,'1'-Да):"
    CHANGE_ADD_EXPLICIT_TAG = "Добавить тег 'Нецензурно' ('0'-Нет,'1'-Да):"
    CHANGE_ADD_HYPHEN = "Использовать дефис вместо пробела в имени трека('0'-Нет,'1'-Да):"
    CHANGE_ADD_YEAR = "Добавлять год перед названием альбома('0'-Нет,'1'-Да):"
    CHANGE_USE_TRACK_NUM = "Добавить номер перед названием трека('0'-Нет,'1'-Да):"
    CHANGE_CHECK_EXIST = "Проверять наличие перед загрузкой('0'-Нет,'1'-Да):"
    CHANGE_ARTIST_BEFORE_TITLE = "Добавить имя артиста перед названием трека('0'-Нет,'1'-Да):"
    CHANGE_INCLUDE_EP = "Включать синглы и миньоны в дискографию('0'-Нет'1'-Да):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Добавить ID перед названием альбома('0'-Нет,'1'-Да):"
    CHANGE_SAVE_COVERS = "Сохранять обложки('0'-Нет,'1'-Да):"
    CHANGE_LANGUAGE = "Выбрать язык"
    CHANGE_ALBUM_FOLDER_FORMAT = "Маска имени альбома('0' не менять):"
    CHANGE_TRACK_FILE_FORMAT = "Маска имени трека('0' не менять):"
    CHANGE_SHOW_PROGRESS = "Показывать процесс загрузки('0'-Нет,'1'-Да):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Сохранять AlbumInfo.txt('0'-Нет,'1'-Да):"
    CHANGE_ADD_LYRICS = "Добавлять тексты песень ('0'-Нет,'1'-Да):"
    CHANGE_LYRICS_SERVER_PROXY = "Прокси для сервера с текстом песень('0' не менять):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Входим в сервис..."
    AUTH_LOGIN_CODE = "Ваш код для входа {}"
    AUTH_NEXT_STEP = "Перейдите к {} в течении {}, для завершения настройки."
    AUTH_WAITING = "Ожидание авторизации..."
    AUTH_TIMEOUT = "Закончилось время ожидания."

    MSG_VALID_ACCESSTOKEN = "AccessToken успешно применён {}."
    MSG_INVAILD_ACCESSTOKEN = "Срок действия AccessToken истек.  Попытка обновления."
    MSG_PATH_ERR = "Неверное место!"
    MSG_INPUT_ERR = "Ошибка ввода!"

    MODEL_ALBUM_PROPERTY = "ALBUM-PROPERTY"
    MODEL_TRACK_PROPERTY = "TRACK-PROPERTY"
    MODEL_VIDEO_PROPERTY = "VIDEO-PROPERTY"
    MODEL_ARTIST_PROPERTY = "ARTIST-PROPERTY"
    MODEL_PLAYLIST_PROPERTY = "PLAYLIST-PROPERTY"

    MODEL_TITLE = 'Название'
    MODEL_TRACK_NUMBER = 'Номер трека'
    MODEL_VIDEO_NUMBER = 'Номер видео'
    MODEL_RELEASE_DATE = 'Дата издания'
    MODEL_VERSION = 'Версия'
    MODEL_EXPLICIT = 'Нецензурно'
    MODEL_ALBUM = 'Альбом'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Имя'
    MODEL_TYPE = 'Тип'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   portuguese.py
@Time    :   2020/08/19
@Author  :   BR8N0BL4CK & João 
@Version :   1.0
@Contact :   
@Desc    :   
'''


class LangPortuguese(object):
    SETTING = "Configurações"
    VALUE = "VALOR"
    SETTING_DOWNLOAD_PATH = "Caminho do download"
    SETTING_ONLY_M4A = "Converter mp4 para m4a"
    SETTING_ADD_EXPLICIT_TAG = "Adicionar etiqueta explícito"
    SETTING_ADD_HYPHEN = "Adicionar hífen"
    SETTING_ADD_YEAR = "Adicionar ano antes do nome do álbum na pasta"
    SETTING_USE_TRACK_NUM = "Adicionar Número da Faixa"
    SETTING_AUDIO_QUALITY = "Qualidade Do Áudio"
    SETTING_VIDEO_QUALITY = "Qualidade Do Vídeo"
    SETTING_CHECK_EXIST = "Verificar Existência"
    SETTING_ARTIST_BEFORE_TITLE = "ArtistaNome Antes do Track-Título"
    SETTING_ALBUMID_BEFORE_FOLDER = "Número De Identificação do Álbum antes na Pasta"
    SETTING_INCLUDE_EP = "Incluir Single & EP"
    SETTING_SAVE_COVERS = "Salvar Capas"
    SETTING_LANGUAGE = "idioma"
    SETTING_USE_PLAYLIST_FOLDER = "Use playlist folder"
    SETTING_MULITHREAD_DOWNLOAD = "Multi thread download"
    SETTING_ALBUM_FOLDER_FORMAT = "Album folder format"
    SETTING_TRACK_FILE_FORMAT = "Track file format"
    SETTING_SHOW_PROGRESS = "Show progress"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Save AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Add lyrics"
    SETTING_LYRICS_SERVER_PROXY = "Lyrics server proxy"
    SETTING_PATH = "Settings path"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "ESCOLHER"
    FUNCTION = "FUNÇÃO"
    CHOICE_ENTER = "Entrar"
    CHOICE_ENTER_URLID = "ADICIONAR 'Url/ID':"
    CHOICE_EXIT = "SAIR"
    CHOICE_LOGIN = "Check AccessToken"
    CHOICE_SETTINGS = "Configurações"
    CHOICE_SET_ACCESS_TOKEN = "Adicionar Token de Acesso"
    CHOICE_DOWNLOAD_BY_URL = "Download Por url ou id"
    CHOICE_LOGOUT = "Logout"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[ERRO]"
    PRINT_INFO = "[INFORMAÇÕES]"
    PRINT_SUCCESS = "[SUCESSO]"

    PRINT_ENTER_CHOICE = "Entrar em Escolher:"
    PRINT_LATEST_VERSION = "Última Versão:"
    # PRINT_USERNAME = "Nome De Usuário:"
    # PRINT_PASSWORD = "Senha:"

    CHANGE_START_SETTINGS = "Configurações Iniciais('0'-Retornar,'1'-Sim):"
    CHANGE_DOWNLOAD_PATH = "Caminho do download('0' Não Modificar):"
    CHANGE_AUDIO_QUALITY = "Qualidade De Áudio('0'-Normal,'1'-Alta,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "Qualidade Do Vídeo(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Converter mp4 para m4a('0'-Não,'1'-Sim):"
    CHANGE_ADD_EXPLICIT_TAG = "Adicionar Etiqueta Explícito para os nomes dos arquivos('0'-Não,'1'-Sim):"
    CHANGE_ADD_HYPHEN = "Usar hífen em vez de espaços nos nomes dos arquivos('0'-Não,'1'-Sim):"
    CHANGE_ADD_YEAR = "Adicionar Ano aos nomes das pastas dos álbums('0'-Não,'1'-Sim):"
    CHANGE_USE_TRACK_NUM = "Adicionar número da faixa antes do nome do arquivo('0'-Não,'1'-Sim):"
    CHANGE_CHECK_EXIST = "Verificar existência do arquivo antes de baixar a faixa('0'-Não,'1'-Sim):"
    CHANGE_ARTIST_BEFORE_TITLE = "Adicionar o nome do artista antes do título da faixa('0'-Não,'1'-Sim):"
    CHANGE_INCLUDE_EP = "Incluir singles e EPs quando baixar álbums de um artista('0'-Não,'1'-Sim):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Adicionar id antes no nome da pasta do álbum('0'-Não,'1'-Sim):"
    CHANGE_SAVE_COVERS = "Salvar Capas('0'-Não,'1'-Sim):"
    CHANGE_LANGUAGE = "Selecionar idioma"
    CHANGE_ALBUM_FOLDER_FORMAT = "Album folder format('0' not modify):"
    CHANGE_TRACK_FILE_FORMAT = "Track file format('0' not modify):"
    CHANGE_SHOW_PROGRESS = "Show progress('0'-No,'1'-Yes):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Save AlbumInfo.txt('0'-No,'1'-Yes):"
    CHANGE_ADD_LYRICS = "Add lyrics('0'-No,'1'-Yes):"
    CHANGE_LYRICS_SERVER_PROXY = "Lyrics server proxy('0' not modify):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Starting login process..."
    AUTH_LOGIN_CODE = "Your login code is {}"
    AUTH_NEXT_STEP = "Go to {} within the next {} to complete setup."
    AUTH_WAITING = "Waiting for authorization..."
    AUTH_TIMEOUT = "Operation timed out."

    MSG_VALID_ACCESSTOKEN = "AccessToken good for {}."
    MSG_INVAILD_ACCESSTOKEN = "Expired AccessToken. Attempting to refresh it."
    MSG_PATH_ERR = "Erro no local de salvamento dos arquivos!"
    MSG_INPUT_ERR = "Erro de Entrada!"

    MODEL_ALBUM_PROPERTY = "ÁLBUM-PROPRIEDADE"
    MODEL_TRACK_PROPERTY = "FAIXA-PROPRIEDADE"
    MODEL_VIDEO_PROPERTY = "VÍDEO-PROPRIEDADE"
    MODEL_ARTIST_PROPERTY = "ARTISTA-PROPRIEDADE"
    MODEL_PLAYLIST_PROPERTY = "PLAYLIST-PPROPRIEDADE"

    MODEL_TITLE = 'Título'
    MODEL_TRACK_NUMBER = 'Número Da Faixa'
    MODEL_VIDEO_NUMBER = 'Número Do Vídeo'
    MODEL_RELEASE_DATE = 'Data De Lançamento'
    MODEL_VERSION = 'Versão'
    MODEL_EXPLICIT = 'Explícito'
    MODEL_ALBUM = 'Álbum'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Nome'
    MODEL_TYPE = 'Tipo'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   __init__.py
@Time    :   2020/11/08
@Author  :   Yaronzz
@Version :   2.1
@Contact :   yaronhuang@foxmail.com
@Desc    :   
'''
import base64
import getopt
import logging
import ssl
import sys
import time

from aigpy.cmdHelper import green, yellow
from aigpy.pathHelper import mkdirs
from aigpy.pipHelper import getLastVersion
from aigpy.stringHelper import isNull
from aigpy.systemHelper import cmpVersion

from tidal_dl.download import start
from tidal_dl.enums import AudioQuality, VideoQuality, Type
from tidal_dl.lang.language import setLang, initLang, getLangChoicePrint
from tidal_dl.printf import Printf, VERSION
from tidal_dl.settings import Settings, TokenSettings, getLogPath
from tidal_dl.tidal import TidalAPI
from tidal_dl.util import API, CONF, TOKEN, LANG, displayTime, loginByConfig, loginByWeb
import tidal_dl.apiKey as apiKey

ssl._create_default_https_context = ssl._create_unverified_context

def login():
    print(LANG.AUTH_START_LOGIN)
    msg, check = API.getDeviceCode()
    if not check:
        Printf.err(msg)
        return

    # print(LANG.AUTH_LOGIN_CODE.format(green(API.key.userCode)))
    print(LANG.AUTH_NEXT_STEP.format(green("http://" + API.key.verificationUrl + "/" + API.key.userCode), yellow(displayTime(API.key.authCheckTimeout))))
    print(LANG.AUTH_WAITING)
    loginByWeb()
    return


def setAccessToken():
    while True:
        print("-------------AccessToken---------------")
        token = Printf.enter("accessToken('0' go back):")
        if token == '0':
            return
        msg, check = API.loginByAccessToken(token, TOKEN.userid)
        if not check:
            Printf.err(msg)
            continue
        break

    print("-------------RefreshToken---------------")
    refreshToken = Printf.enter("refreshToken('0' to skip):")
    if refreshToken == '0':
        refreshToken = TOKEN.refreshToken

    TOKEN.assesstoken = token
    TOKEN.refreshToken = refreshToken
    TOKEN.expiresAfter = 0
    TokenSettings.save(TOKEN)


def setAPIKey():
    global LANG
    item = apiKey.getItem(CONF.apiKeyIndex)
    Printf.info(f'Current APIKeys: {str(CONF.apiKeyIndex)} {item["platform"]}-{item["formats"]}')
    Printf.apikeys(apiKey.getItems())
    index = int(Printf.enterLimit("APIKEY index:", LANG.MSG_INPUT_ERR, apiKey.getLimitIndexs()))
    
    if index != CONF.apiKeyIndex:
        CONF.apiKeyIndex = index
        Settings.save(CONF)
        API.apiKey = apiKey.getItem(index)
        return True
    return False


def checkLogin():
    if loginByConfig():
        return
    login()
    return


def checkLogout():
    login()
    return


def changeSettings():
    global LANG
    Printf.settings(CONF)
    choice = Printf.enter(LANG.CHANGE_START_SETTINGS)
    if choice == '0':
        return

    CONF.downloadPath = Printf.enterPath(LANG.CHANGE_DOWNLOAD_PATH, LANG.MSG_PATH_ERR, '0', CONF.downloadPath)
    CONF.audioQuality = AudioQuality(int(Printf.enterLimit(
        LANG.CHANGE_AUDIO_QUALITY, LANG.MSG_INPUT_ERR, ['0', '1', '2', '3'])))
    CONF.videoQuality = VideoQuality(int(Printf.enterLimit(
        LANG.CHANGE_VIDEO_QUALITY, LANG.MSG_INPUT_ERR, ['1080', '720', '480', '360'])))
    CONF.onlyM4a = Printf.enter(LANG.CHANGE_ONLYM4A) == '1'
    CONF.checkExist = Printf.enter(LANG.CHANGE_CHECK_EXIST) == '1'
    CONF.includeEP = Printf.enter(LANG.CHANGE_INCLUDE_EP) == '1'
    CONF.saveCovers = Printf.enter(LANG.CHANGE_SAVE_COVERS) == '1'
    CONF.showProgress = Printf.enter(LANG.CHANGE_SHOW_PROGRESS) == '1'
    CONF.saveAlbumInfo = Printf.enter(LANG.CHANGE_SAVE_ALBUM_INFO) == '1'
    CONF.showTrackInfo = Printf.enter(LANG.CHANGE_SHOW_TRACKINFO) == '1'
    CONF.usePlaylistFolder = Printf.enter(LANG.SETTING_USE_PLAYLIST_FOLDER + "('0'-No,'1'-Yes):") == '1'
    CONF.language = Printf.enter(LANG.CHANGE_LANGUAGE + "(" + getLangChoicePrint() + "):")
    CONF.albumFolderFormat = Printf.enterFormat(
        LANG.CHANGE_ALBUM_FOLDER_FORMAT, CONF.albumFolderFormat, Settings.getDefaultAlbumFolderFormat())
    CONF.trackFileFormat = Printf.enterFormat(LANG.CHANGE_TRACK_FILE_FORMAT,
                                              CONF.trackFileFormat, Settings.getDefaultTrackFileFormat())
    CONF.addLyrics = Printf.enter(LANG.CHANGE_ADD_LYRICS) == '1'
    CONF.lyricsServerProxy = Printf.enterFormat(
        LANG.CHANGE_LYRICS_SERVER_PROXY, CONF.lyricsServerProxy, CONF.lyricsServerProxy)
    CONF.lyricFile = Printf.enter(LANG.CHANGE_ADD_LRC_FILE) == '1'
    CONF.addTypeFolder = Printf.enter(LANG.CHANGE_ADD_TYPE_FOLDER) == '1'

    LANG = setLang(CONF.language)
    Settings.save(CONF)


def mainCommand():
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hvl:o:q:r:", ["help", "version",
                                                                "link=", "output=", "quality", "resolution"])
    except getopt.GetoptError as errmsg:
        Printf.err(vars(errmsg)['msg'] + ". Use 'tidal-dl -h' for useage.")
        return

    link = None
    for opt, val in opts:
        if opt in ('-h', '--help'):
            Printf.usage()
            continue
        if opt in ('-v', '--version'):
            Printf.logo()
            continue
        if opt in ('-l', '--link'):
            checkLogin()
            link = val
            continue
        if opt in ('-o', '--output'):
            CONF.downloadPath = val
            Settings.save(CONF)
            continue
        if opt in ('-q', '--quality'):
            CONF.audioQuality = Settings.getAudioQuality(val)
            Settings.save(CONF)
            continue
        if opt in ('-r', '--resolution'):
            CONF.videoQuality = Settings.getVideoQuality(val)
            Settings.save(CONF)
            continue

    if not mkdirs(CONF.downloadPath):
        Printf.err(LANG.MSG_PATH_ERR + CONF.downloadPath)
        return

    if link is not None:
        Printf.info(LANG.SETTING_DOWNLOAD_PATH + ':' + CONF.downloadPath)
        start(TOKEN, CONF, link)


def debug():
    checkLogin()
    API.key.accessToken = TOKEN.accessToken
    API.key.userId = TOKEN.userid
    API.key.countryCode = TOKEN.countryCode
    # https://api.tidal.com/v1/mixes/{01453963b7dbd41c8b82ccb678d127/items?countryCode={country}
    API.getMix("01453963b7dbd41c8b82ccb678d127")
    # msg, result = API.search('Mojito', Type.Null, 0, 10)
    msg, lyric = API.getLyrics('144909909')
    pass


def main():
    if len(sys.argv) > 1:
        mainCommand()
        return

    Printf.logo()
    Printf.settings(CONF)

    checkLogin()

    # onlineVer = getLastVersion('tidal-dl')
    # if not isNull(onlineVer):
    #     icmp = cmpVersion(onlineVer, VERSION)
    #     if icmp > 0:
    #         Printf.info(LANG.PRINT_LATEST_VERSION + ' ' + onlineVer)

    # Printf.info("For some reasons, this version only supports LOSSLESS.")

    while True:
        Printf.choices()
        choice = Printf.enter(LANG.PRINT_ENTER_CHOICE)
        if choice == "0":
            return
        elif choice == "1":
            checkLogin()
        elif choice == "2":
            changeSettings()
        elif choice == "3":
            checkLogout()
        elif choice == "4":
            setAccessToken()
        elif choice == '5':
            if setAPIKey():
                checkLogout()
        elif choice == "10":  # test track
            start(TOKEN, CONF, '70973230')
        elif choice == "11":  # test video
            start(TOKEN, CONF, '188932980')
        elif choice == "12":  # test album
            start(TOKEN, CONF, '58138532')
        elif choice == "13":  # test playlist
            start(TOKEN, CONF, '98235845-13e8-43b4-94e2-d9f8e603cee7')
        elif choice == "14":  # test playlist
            start(TOKEN, CONF, '01453963b7dbd41c8b82ccb678d127')
        else:
            start(TOKEN, CONF, choice)


if __name__ == "__main__":
    # debug()
    main() 
    # test example
    # track 70973230  77798028 212657
    # video 155608351 188932980
    # album 58138532  77803199  21993753   79151897  56288918
    # playlist 98235845-13e8-43b4-94e2-d9f8e603cee7



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   vietnamese.py
@Time    :   2020/11/12
@Author  :   MinhNgo, CDzungx
@Version :   1.0
@Contact :   iam.minhnc@outlook.com
@Desc    :   
'''


class LangVietnamese(object):
    SETTING = "THIẾT LẬP"
    VALUE = "GIÁ TRỊ"
    SETTING_DOWNLOAD_PATH = "Đường dẫn tải về"
    SETTING_ONLY_M4A = "Đổi mp4 sang m4a"
    SETTING_ADD_EXPLICIT_TAG = "Thêm tag explicit"
    SETTING_ADD_HYPHEN = "Thêm dấu nối"
    SETTING_ADD_YEAR = "Thêm năm trước thư mục album"
    SETTING_USE_TRACK_NUM = "Thêm số thứ tự bài"
    SETTING_AUDIO_QUALITY = "Chất lượng âm thanh"
    SETTING_VIDEO_QUALITY = "Chất lượng video"
    SETTING_CHECK_EXIST = "Kiểm tra tồn tại"
    SETTING_ARTIST_BEFORE_TITLE = "Tên nghệ sĩ phía trước tựa bài hát"
    SETTING_ALBUMID_BEFORE_FOLDER = "Id trước thư mục album"
    SETTING_INCLUDE_EP = "Bao gồm đĩa đơn & ep"
    SETTING_SAVE_COVERS = "Tải ảnh bìa"
    SETTING_LANGUAGE = "Ngôn ngữ"
    SETTING_USE_PLAYLIST_FOLDER = "Thư mục cho danh sách phát"
    SETTING_MULITHREAD_DOWNLOAD = "Tải về đa luồng"
    SETTING_ALBUM_FOLDER_FORMAT = "Định dạng thư mục album"
    SETTING_TRACK_FILE_FORMAT = "Định dạng tên tệp nhạc"
    SETTING_SHOW_PROGRESS = "Hiện tiến trình"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Lưu AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Thêm lời bài hát"
    SETTING_LYRICS_SERVER_PROXY = "Máy chủ proxy cho lyrics"
    SETTINGS_ADD_LRC_FILE = "Lưu timed lyrics (tệp .lrc)"
    SETTING_PATH = "Đường dẫn cài đặt"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "LỰA CHỌN"
    FUNCTION = "CHỨC NĂNG"
    CHOICE_ENTER = "Nhập"
    CHOICE_ENTER_URLID = "Nhập 'Url/ID':"
    CHOICE_EXIT = "Thoát"
    CHOICE_LOGIN = "Kiểm tra AccessToken"
    CHOICE_SETTINGS = "Thiết lập"
    CHOICE_SET_ACCESS_TOKEN = "Nhập AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "Tải về qua url hoặc id"
    CHOICE_LOGOUT = "Đăng xuất"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[LỖI]"
    PRINT_INFO = "[THÔNG TIN]"
    PRINT_SUCCESS = "[XONG]"

    PRINT_ENTER_CHOICE = "Nhập lựa chọn:"
    PRINT_LATEST_VERSION = "Bản mới nhất:"
    # PRINT_USERNAME = "tên đăng nhập:"
    # PRINT_PASSWORD = "mật khẩu:"

    CHANGE_START_SETTINGS = "Bắt đầu thiết lập('0'-Về,'1'-Có):"
    CHANGE_DOWNLOAD_PATH = "Đường dẫn tải về('0' không đổi):"
    CHANGE_AUDIO_QUALITY = "Chất lượng âm thanh('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "Chất lượng video(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "Đổi mp4 sang m4a('0'-Không,'1'-Có):"
    CHANGE_ADD_EXPLICIT_TAG = "Thêm tag explicit vào tên tệp('0'-Không,'1'-Có):"
    CHANGE_ADD_HYPHEN = "Dùng gạch nối thay vì dấu cách trong tên tệp('0'-Không,'1'-Có):"
    CHANGE_ADD_YEAR = "Thêm năm phía trước tên thư mục album('0'-Không,'1'-Có):"
    CHANGE_USE_TRACK_NUM = "Thêm số thứ tự bài ở đầu tên tệp('0'-Không,'1'-Có):"
    CHANGE_CHECK_EXIST = "Kiểm tra tệp đã tồn tại chưa trước khi tải('0'-Không,'1'-Có):"
    CHANGE_ARTIST_BEFORE_TITLE = "Thêm tên nghệ sĩ trước tựa đề('0'-Không,'1'-Có):"
    CHANGE_INCLUDE_EP = "Bao gồm đĩa đơn và EPs khi tải tất cả nhạc của nghệ sĩ('0'-Không,'1'-Có):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Thêm id phía trước tên thư mục album('0'-Không,'1'-Có):"
    CHANGE_SAVE_COVERS = "Tải ảnh bìa('0'-Không,'1'-Có):"
    CHANGE_LANGUAGE = "Chọn ngôn ngữ"
    CHANGE_ALBUM_FOLDER_FORMAT = "Định dạng thư mục album('0' không đổi,'default' để đặt về mặc định):"
    CHANGE_TRACK_FILE_FORMAT = "Định dạng tên tệp nhạc('0' không đổi,'default' để đặt về mặc định):"
    CHANGE_SHOW_PROGRESS = "Hiện tiến trình('0'-Không,'1'-Có):"
    CHANGE_SHOW_TRACKINFO = "Hiện thông tin bài('0'-No,'1'-Yes):"
    CHANGE_SAVE_ALBUM_INFO = "Lưu AlbumInfo.txt('0'-Không,'1'-Có):"
    CHANGE_ADD_LYRICS = "Thêm lời bài hát('0'-Không,'1'-Có):"
    CHANGE_LYRICS_SERVER_PROXY = "Máy chủ proxy cho lyrics('0' không đổi):"
    CHANGE_ADD_LRC_FILE = "Lưu timed lyrics tệp .lrc ('0'-No,'1'-Yes):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Đang bắt đầu đăng nhập..."
    AUTH_LOGIN_CODE = "Mã đăng nhập của bạn là {}"
    AUTH_NEXT_STEP = "Vào trang {} trong vòng {} để hoàn tất thiết lập."
    AUTH_WAITING = "Đang chờ xác minh..."
    AUTH_TIMEOUT = "Đã vượt quá thời gian chờ."

    MSG_VALID_ACCESSTOKEN = "AccessToken vẫn tốt trong {}."
    MSG_INVAILD_ACCESSTOKEN = "AccessToken hết hạn. Đang cố làm mới."
    MSG_PATH_ERR = "Lỗi đường dẫn!"
    MSG_INPUT_ERR = "Lỗi nhập!"

    MODEL_ALBUM_PROPERTY = "THÔNG-TIN-ALBUM"
    MODEL_TRACK_PROPERTY = "THÔNG-TIN-BÀI"
    MODEL_VIDEO_PROPERTY = "THÔNG-TIN-VIDEO"
    MODEL_ARTIST_PROPERTY = "THÔNG-TIN-NGHỆ-SĨ"
    MODEL_PLAYLIST_PROPERTY = "THÔNG-TIN-DANH-SÁCH-PHÁT"

    MODEL_TITLE = 'Tựa Đề'
    MODEL_TRACK_NUMBER = 'Số Bài'
    MODEL_VIDEO_NUMBER = 'Số Video'
    MODEL_RELEASE_DATE = 'Ngày Phát Hành'
    MODEL_VERSION = 'Phiên Bản'
    MODEL_EXPLICIT = 'Explicit'
    MODEL_ALBUM = 'Album'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Tên'
    MODEL_TYPE = 'Loại'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :  util.py
@Date    :  2021/10/09
@Author  :  Yaronzz
@Version :  1.0
@Contact :  yaronhuang@foxmail.com
@Desc    :  
"""

import logging
import os
import time
import requests

import aigpy
import lyricsgenius
import datetime
from tidal_dl import apiKey
import tidal_dl
from tidal_dl.decryption import decrypt_file
from tidal_dl.decryption import decrypt_security_token
from tidal_dl.enums import Type, AudioQuality
from tidal_dl.lang.language import initLang
from tidal_dl.model import Track, Video, Lyrics, Mix, Album
from tidal_dl.printf import Printf
from tidal_dl.settings import Settings, TokenSettings, getLogPath
from tidal_dl.tidal import TidalAPI

TOKEN = TokenSettings.read()
CONF = Settings.read()
LANG = initLang(CONF.language)
API = TidalAPI()
API.apiKey = apiKey.getItem(CONF.apiKeyIndex)

logging.basicConfig(filename=getLogPath(),
                    level=logging.INFO,
                    format='%(asctime)s - %(levelname)s: %(message)s')


def __getIndexStr__(index):
    pre = "0"
    if index < 10:
        return pre + str(index)
    if index < 99:
        return str(index)
    return str(index)


def __getExtension__(url):
    if '.flac' in url:
        return '.flac'
    if '.mp4' in url:
        return '.mp4'
    return '.m4a'


def __secondsToTimeStr__(seconds):
    time_string = str(datetime.timedelta(seconds=seconds))
    if time_string.startswith('0:'):
        time_string = time_string[2:]
    return time_string


def __parseContributors__(roleType, Contributors):
    if Contributors is None:
        return None
    try:
        ret = []
        for item in Contributors['items']:
            if item['role'] == roleType:
                ret.append(item['name'])
        return ret
    except:
        return None


GEMIUS = lyricsgenius.Genius('vNKbAWAE3rVY_48nRaiOrDcWNLvsxS-Z8qyG5XfEzTOtZvkTfg6P3pxOVlA2BjaW')


def getLyricsFromGemius(trackName, artistName, proxy):
    try:
        if not aigpy.string.isNull(proxy):
            GEMIUS._session.proxies = {
                'http': f'http://{proxy}',
                'https': f'http://{proxy}',
            }

        song = GEMIUS.search_song(trackName, artistName)
        return song.lyrics
    except:
        return ""


def stripPathParts(stripped_path, separator):
    result = ""
    stripped_path = stripped_path.split(separator)
    for stripped_path_part in stripped_path:
        result += stripped_path_part.strip()
        if not stripped_path.index(stripped_path_part) == len(stripped_path) - 1:
            result += separator
    return result.strip()


def stripPath(path):
    result = stripPathParts(path, "/")
    result = stripPathParts(result, "\\")
    return result.strip()


def getArtistsName(artists):
    return ", ".join(map(lambda artist: artist.name, artists))


# "{ArtistName}/{Flag} [{AlbumID}] [{AlbumYear}] {AlbumTitle}"
def getAlbumPath(conf: Settings, album):
    base = conf.downloadPath + '/'
    if conf.addTypeFolder:
        base = base + 'Album/'
    artist = aigpy.path.replaceLimitChar(getArtistsName(album.artists), '-')
    albumArtistName = album.artist.name if album.artist is not None else ""
    # album folder pre: [ME][ID]
    flag = API.getFlag(album, Type.Album, True, "")
    if conf.audioQuality != AudioQuality.Master:
        flag = flag.replace("M", "")
    if not conf.addExplicitTag:
        flag = flag.replace("E", "")
    if not aigpy.string.isNull(flag):
        flag = "[" + flag + "] "

    sid = str(album.id)
    # album and addyear
    albumname = aigpy.path.replaceLimitChar(album.title, '-')
    year = ""
    if album.releaseDate is not None:
        year = aigpy.string.getSubOnlyEnd(album.releaseDate, '-')
    # retpath
    retpath = conf.albumFolderFormat
    if retpath is None or len(retpath) <= 0:
        retpath = Settings.getDefaultAlbumFolderFormat()
    retpath = retpath.replace(R"{ArtistName}", artist.strip())
    retpath = retpath.replace(R"{AlbumArtistName}", albumArtistName.strip())
    retpath = retpath.replace(R"{Flag}", flag)
    retpath = retpath.replace(R"{AlbumID}", sid)
    retpath = retpath.replace(R"{AlbumYear}", year)
    retpath = retpath.replace(R"{AlbumTitle}", albumname.strip())
    retpath = retpath.replace(R"{AudioQuality}", album.audioQuality)
    retpath = retpath.replace(R"{DurationSeconds}", str(album.duration))
    retpath = retpath.replace(R"{Duration}", __secondsToTimeStr__(album.duration))
    retpath = retpath.replace(R"{NumberOfTracks}", str(album.numberOfTracks))
    retpath = retpath.replace(R"{NumberOfVideos}", str(album.numberOfVideos))
    retpath = retpath.replace(R"{NumberOfVolumes}", str(album.numberOfVolumes))
    retpath = retpath.replace(R"{ReleaseDate}", str(album.releaseDate))
    retpath = retpath.replace(R"{RecordType}", album.type)
    retpath = retpath.replace(R"{None}", "")
    retpath = stripPath(retpath.strip())
    return base + retpath


def getPlaylistPath(conf: Settings, playlist):
    # outputdir/Playlist/
    base = conf.downloadPath + '/'
    if conf.addTypeFolder:
        base = base + 'Playlist/'
    # name
    name = aigpy.path.replaceLimitChar(playlist.title, '-')
    return base + name + '/'


def getTrackPath(conf: Settings, track, stream, album=None, playlist=None):
    base = './'
    if album is not None:
        base = getAlbumPath(conf, album) + '/'
        if album.numberOfVolumes > 1:
            base += 'CD' + str(track.volumeNumber) + '/'
    if playlist is not None and conf.usePlaylistFolder:
        base = getPlaylistPath(conf, playlist)
    # number
    number = __getIndexStr__(track.trackNumber)
    if playlist is not None and conf.usePlaylistFolder:
        number = __getIndexStr__(track.trackNumberOnPlaylist)
    # artist
    artists = aigpy.path.replaceLimitChar(getArtistsName(track.artists), '-')
    artist = track.artist.name if track.artist is not None else ""
    # title
    title = track.title
    if not aigpy.string.isNull(track.version):
        title += ' (' + track.version + ')'
    title = aigpy.path.replaceLimitChar(title, '-')
    # get explicit
    explicit = "(Explicit)" if conf.addExplicitTag and track.explicit else ''
    # album and addyear
    albumname = aigpy.path.replaceLimitChar(album.title, '-')
    year = ""
    if album.releaseDate is not None:
        year = aigpy.string.getSubOnlyEnd(album.releaseDate, '-')
    # extension
    extension = __getExtension__(stream.url)
    retpath = conf.trackFileFormat
    if retpath is None or len(retpath) <= 0:
        retpath = Settings.getDefaultTrackFileFormat()
    retpath = retpath.replace(R"{TrackNumber}", number)
    retpath = retpath.replace(R"{ArtistName}", artist.strip())
    retpath = retpath.replace(R"{ArtistsName}", artists.strip())
    retpath = retpath.replace(R"{TrackTitle}", title)
    retpath = retpath.replace(R"{ExplicitFlag}", explicit)
    retpath = retpath.replace(R"{AlbumYear}", year)
    retpath = retpath.replace(R"{AlbumTitle}", albumname.strip())
    retpath = retpath.replace(R"{AudioQuality}", track.audioQuality)
    retpath = retpath.replace(R"{DurationSeconds}", str(track.duration))
    retpath = retpath.replace(R"{Duration}", __secondsToTimeStr__(track.duration))
    retpath = retpath.strip()
    return base + retpath + extension


def getVideoPath(conf, video, album=None, playlist=None):
    if album is not None and album.title is not None:
        base = getAlbumPath(conf, album)
    elif playlist is not None and conf.usePlaylistFolder:
        base = getPlaylistPath(conf, playlist)
    else:
        base = conf.downloadPath + '/'
        if conf.addTypeFolder:
            base = base + 'Video/'

    # hyphen
    hyphen = ' - ' if conf.addHyphen else ' '
    # get number
    number = ''
    if conf.useTrackNumber:
        number = __getIndexStr__(video.trackNumber) + hyphen
    # get artist
    artist = ''
    if conf.artistBeforeTitle:
        artist = aigpy.path.replaceLimitChar(getArtistsName(video.artists), '-') + hyphen
    # get explicit
    explicit = "(Explicit)" if conf.addExplicitTag and video.explicit else ''
    # title
    title = aigpy.path.replaceLimitChar(video.title, '-')
    # extension
    extension = ".mp4"
    return base + number + artist.strip() + title + explicit + extension


def convertToM4a(filepath, codec):
    if 'ac4' in codec or 'mha1' in codec:
        return filepath
    if '.mp4' not in filepath:
        return filepath
    newpath = filepath.replace('.mp4', '.m4a')
    aigpy.path.remove(newpath)
    os.rename(filepath, newpath)
    return newpath


def setMetaData(track, album, filepath, contributors, lyrics):
    obj = aigpy.tag.TagTool(filepath)
    obj.album = track.album.title
    obj.title = track.title
    if not aigpy.string.isNull(track.version):
        obj.title += ' (' + track.version + ')'

    obj.artist = list(map(lambda artist: artist.name, track.artists))  # __getArtists__(track.artists)
    obj.copyright = track.copyRight
    obj.tracknumber = track.trackNumber
    obj.discnumber = track.volumeNumber
    obj.composer = __parseContributors__('Composer', contributors)
    obj.isrc = track.isrc

    obj.albumartist = list(map(lambda artist: artist.name, album.artists))  # __getArtists__(album.artists)
    obj.date = album.releaseDate
    obj.totaldisc = album.numberOfVolumes
    obj.lyrics = lyrics
    if obj.totaldisc <= 1:
        obj.totaltrack = album.numberOfTracks
    coverpath = API.getCoverUrl(album.cover, "1280", "1280")
    obj.save(coverpath)
    return


def isNeedDownload(path, url):
    curSize = aigpy.file.getSize(path)
    if curSize <= 0:
        return True
    netSize = aigpy.net.getSize(url)
    if curSize >= netSize:
        return False
    return True


def encrypted(stream, srcPath, descPath):
    if aigpy.string.isNull(stream.encryptionKey):
        os.replace(srcPath, descPath)
    else:
        key, nonce = decrypt_security_token(stream.encryptionKey)
        decrypt_file(srcPath, descPath, key, nonce)
        os.remove(srcPath)


def getAudioQualityList():
    return map(lambda quality: quality.name, tidal_dl.enums.AudioQuality)

def getCurAudioQuality():
    return CONF.audioQuality.name

def setCurAudioQuality(text):
    if CONF.audioQuality.name == text:
        return
    for item in tidal_dl.enums.AudioQuality:
        if item.name == text:
            CONF.audioQuality = item
            break
    Settings.save(CONF)

def getVideoQualityList():
    return map(lambda quality: quality.name, tidal_dl.enums.VideoQuality)

def getCurVideoQuality():
    return CONF.videoQuality.name

def setCurVideoQuality(text):
    if CONF.videoQuality.name == text:
        return
    for item in tidal_dl.enums.VideoQuality:
        if item.name == text:
            CONF.videoQuality = item
            break
    Settings.save(CONF)

def skip(path, url):
    if CONF.checkExist and isNeedDownload(path, url) is False:
        return True
    return False


def convert(srcPath, stream):
    if CONF.onlyM4a:
        return convertToM4a(srcPath, stream.codec)
    return srcPath


def downloadTrack(track: Track, album=None, playlist=None, userProgress=None, partSize=1048576):
    try:
        msg, stream = API.getStreamUrl(track.id, CONF.audioQuality)
        if not aigpy.string.isNull(msg) or stream is None:
            Printf.err(track.title + "." + msg)
            return False, msg
        if CONF.showTrackInfo:
            Printf.track(track, stream)
        if userProgress is not None:
            userProgress.updateStream(stream)
        path = getTrackPath(CONF, track, stream, album, playlist)

        # check exist
        if skip(path, stream.url):
            Printf.success(aigpy.path.getFileName(path) + " (skip:already exists!)")
            return True, ""

        # download
        logging.info("[DL Track] name=" + aigpy.path.getFileName(path) + "\nurl=" + stream.url)
        tool = aigpy.download.DownloadTool(path + '.part', [stream.url])
        tool.setUserProgress(userProgress)
        tool.setPartSize(partSize)
        check, err = tool.start(CONF.showProgress)
        if not check:
            Printf.err("Download failed! " + aigpy.path.getFileName(path) + ' (' + str(err) + ')')
            return False, str(err)

        # encrypted -> decrypt and remove encrypted file
        encrypted(stream, path + '.part', path)

        # convert
        path = convert(path, stream)

        # contributors
        msg, contributors = API.getTrackContributors(track.id)
        msg, tidalLyrics = API.getLyrics(track.id)

        lyrics = '' if tidalLyrics is None else tidalLyrics.subtitles
        if CONF.lyricFile:
            if tidalLyrics is None:
                Printf.info(f'Failed to get lyrics from tidal!"{track.title}"')
            else:
                lrcPath = path.rsplit(".", 1)[0] + '.lrc'
                aigpy.fileHelper.write(lrcPath, tidalLyrics.subtitles, 'w')

        setMetaData(track, album, path, contributors, lyrics)
        Printf.success(aigpy.path.getFileName(path))
        return True, ""
    except Exception as e:
        Printf.err("Download failed! " + track.title + ' (' + str(e) + ')')
        return False, str(e)


def downloadVideo(video: Video, album=None, playlist=None):
    msg, stream = API.getVideoStreamUrl(video.id, CONF.videoQuality)
    Printf.video(video, stream)
    if not aigpy.string.isNull(msg):
        Printf.err(video.title + "." + msg)
        return False, msg
    path = getVideoPath(CONF, video, album, playlist)

    logging.info("[DL Video] name=" + aigpy.path.getFileName(path) + "\nurl=" + stream.m3u8Url)
    m3u8content = requests.get(stream.m3u8Url).content
    if m3u8content is None:
        Printf.err(video.title + ' get m3u8 content failed.')
        return False, "Get m3u8 content failed"

    urls = aigpy.m3u8.parseTsUrls(m3u8content)
    if len(urls) <= 0:
        Printf.err(video.title + ' parse ts urls failed.')
        logging.info("[DL Video] title=" + video.title + "\m3u8Content=" + str(m3u8content))
        return False, 'Parse ts urls failed.'

    check, msg = aigpy.m3u8.downloadByTsUrls(urls, path)
    # check, msg = aigpy.m3u8.download(stream.m3u8Url, path)
    if check is True:
        Printf.success(aigpy.path.getFileName(path))
        return True, ''
    else:
        Printf.err("\nDownload failed!" + msg + '(' + aigpy.path.getFileName(path) + ')')
        return False, msg


def displayTime(seconds, granularity=2):
    if seconds <= 0:
        return "unknown"

    result = []
    intervals = (
        ('weeks', 604800),
        ('days', 86400),
        ('hours', 3600),
        ('minutes', 60),
        ('seconds', 1),
    )

    for name, count in intervals:
        value = seconds // count
        if value:
            seconds -= value * count
            if value == 1:
                name = name.rstrip('s')
            result.append("{} {}".format(value, name))
    return ', '.join(result[:granularity])

def loginByConfig():
    if aigpy.stringHelper.isNull(TOKEN.accessToken):
        return False

    msg, check = API.verifyAccessToken(TOKEN.accessToken)
    if check:
        Printf.info(LANG.MSG_VALID_ACCESSTOKEN.format(displayTime(int(TOKEN.expiresAfter - time.time()))))
        API.key.countryCode = TOKEN.countryCode
        API.key.userId = TOKEN.userid
        API.key.accessToken = TOKEN.accessToken
        return True

    Printf.info(LANG.MSG_INVAILD_ACCESSTOKEN)
    msg, check = API.refreshAccessToken(TOKEN.refreshToken)
    if check:
        Printf.success(LANG.MSG_VALID_ACCESSTOKEN.format(displayTime(int(API.key.expiresIn))))
        TOKEN.userid = API.key.userId
        TOKEN.countryCode = API.key.countryCode
        TOKEN.accessToken = API.key.accessToken
        TOKEN.expiresAfter = time.time() + int(API.key.expiresIn)
        TokenSettings.save(TOKEN)
        return True
    else:
        tmp = TokenSettings()  # clears saved tokens
        TokenSettings.save(tmp)
        return False

def loginByWeb():
    start = time.time()
    elapsed = 0
    while elapsed < API.key.authCheckTimeout:
        elapsed = time.time() - start
        msg, check = API.checkAuthStatus()
        if not check:
            if msg == "pending":
                time.sleep(API.key.authCheckInterval + 1)
                continue
            return False
        if check:
            Printf.success(LANG.MSG_VALID_ACCESSTOKEN.format(displayTime(int(API.key.expiresIn))))
            TOKEN.userid = API.key.userId
            TOKEN.countryCode = API.key.countryCode
            TOKEN.accessToken = API.key.accessToken
            TOKEN.refreshToken = API.key.refreshToken
            TOKEN.expiresAfter = time.time() + int(API.key.expiresIn)
            TokenSettings.save(TOKEN)
            return True
        
    Printf.err(LANG.AUTH_TIMEOUT)
    return False

def getArtistsNames(artists):  # : list[tidal_dl.model.Artist]
    ret = []
    for item in artists:
        ret.append(item.name)
    return ','.join(ret)

def getDurationString(seconds: int):
    m, s = divmod(seconds, 60)
    h, m = divmod(m, 60)
    return "%02d:%02d:%02d" % (h, m, s)

def getBasePath(model):
    if isinstance(model, tidal_dl.model.Album):
        return getAlbumPath(CONF, model)
    if isinstance(model, tidal_dl.model.Playlist):
        return getPlaylistPath(CONF, model)
    if isinstance(model, tidal_dl.model.Track):
        return getAlbumPath(CONF, model.album)
    if isinstance(model, tidal_dl.model.Video):
        filePath = getVideoPath(CONF, model, model.album, model.playlist)
        return aigpy.pathHelper.getDirName(filePath)
    return './'

def getFilePath(model, stream=None):
    if isinstance(model, tidal_dl.model.Track):
        return getTrackPath(CONF, model, stream, model.album, model.playlist)
    if isinstance(model, tidal_dl.model.Video):
        return getVideoPath(CONF, model, model.album, model.playlist)
    return './'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   japanese.py
@Time    :   2021/11/30
@Author  :   jee019
@Version :   1.0
@Contact :   qwer010910@gmail.com
@Desc    :   
'''


class LangJapanese(object):
    SETTING = "設定"
    VALUE = "値"
    SETTING_DOWNLOAD_PATH = "ダウンロードパス"
    SETTING_ONLY_M4A = "mp4をm4aに変換する"
    SETTING_ADD_EXPLICIT_TAG = "explicitタグ付けする"
    SETTING_ADD_HYPHEN = "ハイフンを追加"
    SETTING_ADD_YEAR = "Add year before album-folder"
    SETTING_USE_TRACK_NUM = "ユーザートラック番号を追加"
    SETTING_AUDIO_QUALITY = "オーディオ品質"
    SETTING_VIDEO_QUALITY = "ビデオ品質"
    SETTING_CHECK_EXIST = "Check exist"
    SETTING_ARTIST_BEFORE_TITLE = "ArtistName before track-title"
    SETTING_ALBUMID_BEFORE_FOLDER = "Id before album-folder"
    SETTING_INCLUDE_EP = "含む singles & EPs"
    SETTING_SAVE_COVERS = "カバーを保存"
    SETTING_LANGUAGE = "言語"
    SETTING_USE_PLAYLIST_FOLDER = "Use playlist folder"
    SETTING_MULITHREAD_DOWNLOAD = "Multi thread download"
    SETTING_ALBUM_FOLDER_FORMAT = "Album folder format"
    SETTING_TRACK_FILE_FORMAT = "Track file format"
    SETTING_SHOW_PROGRESS = "Show progress"
    SETTING_SHOW_TRACKIFNO = "Show Track Info"
    SETTING_SAVE_ALBUMINFO = "Save AlbumInfo.txt"
    SETTING_ADD_LYRICS = "歌詞を追加"
    SETTING_LYRICS_SERVER_PROXY = "Lyrics server proxy"
    SETTINGS_ADD_LRC_FILE = "Save timed lyrics (.lrc file)"
    SETTING_PATH = "設定パス"
    SETTING_APIKEY = "APIKey support"
    SETTING_ADD_TYPE_FOLDER = "Add Type-Folder"

    CHOICE = "選択"
    FUNCTION = "関数"
    CHOICE_ENTER = "エンター"
    CHOICE_ENTER_URLID = "エンター 'Url/ID':"
    CHOICE_EXIT = "エグジット"
    CHOICE_LOGIN = "AccessTokenを確認してください"
    CHOICE_SETTINGS = "セッティング"
    CHOICE_SET_ACCESS_TOKEN = "AccessTokenを設定する"
    CHOICE_DOWNLOAD_BY_URL = "UrlまたはIDでダウンロード"
    CHOICE_LOGOUT = "ログアウト"
    CHOICE_APIKEY = "Select APIKey"

    PRINT_ERR = "[エラー]"
    PRINT_INFO = "[情報]"
    PRINT_SUCCESS = "[サクセス]"

    PRINT_ENTER_CHOICE = "エンター 選択:"
    PRINT_LATEST_VERSION = "最新バージョン:"
    # PRINT_USERNAME = "ユーザー名:"
    # PRINT_PASSWORD = "パスワード:"

    CHANGE_START_SETTINGS = "設定を開始('0'-戻る,'1'-はい):"
    CHANGE_DOWNLOAD_PATH = "ダウンロードパス('0'-変更しない):"
    CHANGE_AUDIO_QUALITY = "オーディオ品質('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "ビデオ品質(1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "mp4をm4aに変換する('0'-いいえ,'1'-はい):"
    CHANGE_ADD_EXPLICIT_TAG = "Add explicit tag to file names('0'-いいえ,'1'-はい):"
    CHANGE_ADD_HYPHEN = "Use hyphens instead of spaces in file names('0'-いいえ,'1'-はい):"
    CHANGE_ADD_YEAR = "Add year to album folder names('0'-いいえ,'1'-はい):"
    CHANGE_USE_TRACK_NUM = "Add track number before file names('0'-いいえ,'1'-はい):"
    CHANGE_CHECK_EXIST = "Check exist file before download track('0'-いいえ,'1'-はい):"
    CHANGE_ARTIST_BEFORE_TITLE = "Add artistName before track title('0'-いいえ,'1'-はい):"
    CHANGE_INCLUDE_EP = "Include singles and EPs when downloading an artist's albums('0'-いいえ,'1'-はい):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "Add id before album folder('0'-いいえ,'1'-はい):"
    CHANGE_SAVE_COVERS = "カバーを保存('0'-いいえ,'1'-はい):"
    CHANGE_LANGUAGE = "言語を選択する"
    CHANGE_ALBUM_FOLDER_FORMAT = "Album folder format('0'-変更しない,'default'-デフォルトを設定するには):"
    CHANGE_TRACK_FILE_FORMAT = "Track file format('0'-変更しない,'default'-デフォルトを設定するには):"
    CHANGE_SHOW_PROGRESS = "Show progress('0'-いいえ,'1'-はい):"
    CHANGE_SHOW_TRACKINFO = "Show track info('0'-いいえ,'1'-はい):"
    CHANGE_SAVE_ALBUM_INFO = "Save AlbumInfo.txt('0'-いいえ,'1'-はい):"
    CHANGE_ADD_LYRICS = "歌詞を追加('0'-いいえ,'1'-はい):"
    CHANGE_LYRICS_SERVER_PROXY = "Lyrics server proxy('0'-変更しない):"
    CHANGE_ADD_LRC_FILE = "Save timed lyrics .lrc file ('0'-いいえ,'1'-はい):"
    CHANGE_ADD_TYPE_FOLDER = "Add Type-Folder,eg Album/Video/Playlist('0'-No,'1'-Yes):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Starting login process..."
    AUTH_LOGIN_CODE = "Your login code is {}"
    AUTH_NEXT_STEP = "Go to {} within the next {} to complete setup."
    AUTH_WAITING = "Waiting for authorization..."
    AUTH_TIMEOUT = "Operation timed out."

    MSG_VALID_ACCESSTOKEN = "AccessToken good for {}."
    MSG_INVAILD_ACCESSTOKEN = "Expired AccessToken. Attempting to refresh it."
    MSG_PATH_ERR = "パスはエラーです!"
    MSG_INPUT_ERR = "入力エラー!"

    MODEL_ALBUM_PROPERTY = "アルバム-情報"
    MODEL_TRACK_PROPERTY = "トラック-情報"
    MODEL_VIDEO_PROPERTY = "ビデオ-情報"
    MODEL_ARTIST_PROPERTY = "アーティスト-情報"
    MODEL_PLAYLIST_PROPERTY = "プレイリスト-情報"

    MODEL_TITLE = '題名'
    MODEL_TRACK_NUMBER = 'トラック番号'
    MODEL_VIDEO_NUMBER = 'ビデオ番号'
    MODEL_RELEASE_DATE = '発売日'
    MODEL_VERSION = 'バージョン'
    MODEL_EXPLICIT = 'Explicit'
    MODEL_ALBUM = 'アルバム'
    MODEL_ID = 'ID'
    MODEL_NAME = '名前'
    MODEL_TYPE = 'タイプ'



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   spanish.py
@Time    :   2022/01/19
@Author  :   Frikilinux & JavierSC
@Version :   2.3
@Contact :
@Desc    :
'''


class LangSpanish(object):
    SETTING = "AJUSTES"
    VALUE = "VALORES"
    SETTING_DOWNLOAD_PATH = "Ruta de descarga"
    SETTING_ONLY_M4A = "Convertir mp4 a m4a"
    SETTING_ADD_EXPLICIT_TAG = "Agregar etiqueta de 'Contenido explícito'"
    SETTING_ADD_HYPHEN = "Agregar guión"
    SETTING_ADD_YEAR = "Agregar año en la carpeta del álbum"
    SETTING_USE_TRACK_NUM = "Agregar número de la pista"
    SETTING_AUDIO_QUALITY = "Calidad de audio"
    SETTING_VIDEO_QUALITY = "Calidad de video"
    SETTING_CHECK_EXIST = "Verificar si existe"
    SETTING_ARTIST_BEFORE_TITLE = "Nombre del artista en el título de la pista"
    SETTING_ALBUMID_BEFORE_FOLDER = "Añadir ID de la carpeta del álbum"
    SETTING_INCLUDE_EP = "Incluir sencillos y EPs"
    SETTING_SAVE_COVERS = "Guardar carátulas"
    SETTING_LANGUAGE = "Idioma"
    SETTING_USE_PLAYLIST_FOLDER = "Usar directorio de la lista de reproducción"
    SETTING_MULITHREAD_DOWNLOAD = "Descarga Multi-hilo"
    SETTING_ALBUM_FOLDER_FORMAT = "Formato del nombre de carpeta del álbum"
    SETTING_TRACK_FILE_FORMAT = "Formato del nombre de archivo de la pista"
    SETTING_SHOW_PROGRESS = "Mostrar progreso"
    SETTING_SHOW_TRACKIFNO = "Mostrar información de pista"
    SETTING_SAVE_ALBUMINFO = "Guardar AlbumInfo.txt"
    SETTING_ADD_LYRICS = "Añadir letras"
    SETTING_LYRICS_SERVER_PROXY = "Proxy del servidor de letras"
    SETTING_PATH = "Ruta de ajustes"
    SETTINGS_ADD_LRC_FILE = "Añadir letras cronometradas (archivo .lrc)"
    SETTING_APIKEY = "Soporte de la APIKey"
    SETTING_ADD_TYPE_FOLDER = "Añadir tipo de carpeta"

    CHOICE = "SELECCIÓN"
    FUNCTION = "FUNCIÓN"
    CHOICE_ENTER = "Ingresar"
    CHOICE_ENTER_URLID = "Ingresar 'Url/ID':"
    CHOICE_EXIT = "Salir"
    CHOICE_LOGIN = "Verificar el token de acceso"
    CHOICE_SETTINGS = "Ajustes"
    CHOICE_SET_ACCESS_TOKEN = "Establecer AccessToken"
    CHOICE_DOWNLOAD_BY_URL = "Descargar por Url o ID"
    CHOICE_LOGOUT = "Cerrar sesión"
    CHOICE_APIKEY = "Seleccionar APIKey"

    PRINT_ERR = "[ERROR]"
    PRINT_INFO = "[INFO]"
    PRINT_SUCCESS = "[ÉXITO]"

    PRINT_ENTER_CHOICE = "Ingresar Selección:"
    PRINT_LATEST_VERSION = "Última versión:"
    # PRINT_USERNAME = "nombre de usuario:"
    # PRINT_PASSWORD = "contraseña:"

    CHANGE_START_SETTINGS = "¿Iniciar ajustes? ('0'-Volver,'1'-Sí):"
    CHANGE_DOWNLOAD_PATH = "Ruta de descarga ('0' No modificar):"
    CHANGE_AUDIO_QUALITY = "Calidad de audio ('0'-Normal,'1'-High,'2'-HiFi,'3'-Master):"
    CHANGE_VIDEO_QUALITY = "Calidad de video (1080, 720, 480, 360):"
    CHANGE_ONLYM4A = "¿Convertir mp4 a m4a? ('0'-No,'1'-Sí):"
    CHANGE_ADD_EXPLICIT_TAG = "¿Agregar etiqueta de contenido explícito a los nombres de archivo? ('0'-No,'1'-Sí):"
    CHANGE_ADD_HYPHEN = "¿Usar guiones en lugar de espacios en el nombre de los archivos? ('0'-No,'1'-Sí):"
    CHANGE_ADD_YEAR = "¿Agregar año a el nombre de las carpetas del álbum? ('0'-No,'1'-Sí):"
    CHANGE_USE_TRACK_NUM = "¿Agregar número de la pista? ('0'-No,'1'-Sí):"
    CHANGE_CHECK_EXIST = "¿Verificar si el archivo existe antes de descargar la pista? ('0'-No,'1'-Sí):"
    CHANGE_ARTIST_BEFORE_TITLE = "¿Añadir el nombre del artista en el título de la pista? ('0'-No,'1'-Sí):"
    CHANGE_INCLUDE_EP = "¿Incluir Sencillos y EPs al descargar el álbum del artista? ('0'-No,'1'-Sí):"
    CHANGE_ALBUMID_BEFORE_FOLDER = "¿Añadir ID de la carpeta del álbum? ('0'-No,'1'-Sí):"
    CHANGE_SAVE_COVERS = "¿Guardar carátulas?('0'-No,'1'-Sí):"
    CHANGE_LANGUAGE = "Seleccione el idioma"
    CHANGE_ALBUM_FOLDER_FORMAT = "Formato del nombre de carpeta del álbum ('0' No modificar):"
    CHANGE_TRACK_FILE_FORMAT = "Formato del nombre de archivo de la pista ('0' No modificar):"
    CHANGE_SHOW_PROGRESS = "¿Mostrar progreso? ('0'-No,'1'-Sí):"
    CHANGE_SHOW_TRACKINFO = "¿Mostrar información de pista?('0'-No,'1'-Sí):"
    CHANGE_SAVE_ALBUM_INFO = "¿Guardar AlbumInfo.txt?('0'-No,'1'-Sí):"
    CHANGE_ADD_LYRICS = "¿Añadir letras?('0'-No,'1'-Sí):"
    CHANGE_LYRICS_SERVER_PROXY = "¿Proxy del servidor de letras?('0' no modificar):"
    CHANGE_ADD_LRC_FILE = "¿Añadir letras cronometradas en un archivo .lrc? ('0'-No,'1'-Sí):"
    CHANGE_ADD_TYPE_FOLDER = "Añadir tipo de carpeta, ej: Album/Video/Playlist('0'-No,'1'-Sí):"

    # {} are required in these strings
    AUTH_START_LOGIN = "Iniciando sesión..."
    AUTH_LOGIN_CODE = "Su código para autorizar la sesión es {}"
    AUTH_NEXT_STEP = "Diríjase a {} en los próximos {} para completar la autorización."
    AUTH_WAITING = "Esperando la autorización..."
    AUTH_TIMEOUT = "Se superó el tiempo de espera."

    MSG_VALID_ACCESSTOKEN = "Token de acceso válido por {}."
    MSG_INVAILD_ACCESSTOKEN = "El token de acceso ha expirado. Tratando de renovarlo."
    MSG_PATH_ERR = "¡La ruta no es correcta!"
    MSG_INPUT_ERR = "¡Error de entrada!"

    MODEL_ALBUM_PROPERTY = "PROPIEDAD-DE-ÁLBUM"
    MODEL_TRACK_PROPERTY = "PROPIEDAD-DE-PISTA"
    MODEL_VIDEO_PROPERTY = "PROPIEDAD-DE-VIDEO"
    MODEL_ARTIST_PROPERTY = "PROPIEDAD-DE-ARTISTA"
    MODEL_PLAYLIST_PROPERTY = "PROPIEDAD-DE-PLAYLIST"

    MODEL_TITLE = 'Título'
    MODEL_TRACK_NUMBER = 'Numero de pistas'
    MODEL_VIDEO_NUMBER = 'Numero de videos'
    MODEL_RELEASE_DATE = 'Fecha de lanzamiento'
    MODEL_VERSION = 'Versión'
    MODEL_EXPLICIT = 'Explícito'
    MODEL_ALBUM = 'Álbum'
    MODEL_ID = 'ID'
    MODEL_NAME = 'Nombre'
    MODEL_TYPE = 'Tipo'
